@@ -67,6 +67,12 @@ pub struct RegisterBlock {
     pub sws: crate::Reg<sws::SWS_SPEC>,
     #[doc = "0xb0 - Interrupt Status Clear"]
     pub swr: crate::Reg<swr::SWR_SPEC>,
+    #[doc = "0xb4 - Shadow transfer control"]
+    pub stc: crate::Reg<stc::STC_SPEC>,
+    #[doc = "0xb8 - Extended Read Back 0"]
+    pub ecrd0: crate::Reg<ecrd0::ECRD0_SPEC>,
+    #[doc = "0xbc - Extended Read Back 1"]
+    pub ecrd1: crate::Reg<ecrd1::ECRD1_SPEC>,
 }
 #[doc = "INS register accessor: an alias for `Reg<INS_SPEC>`"]
 pub type INS = crate::Reg<ins::INS_SPEC>;
@@ -196,3 +202,15 @@ pub mod sws;
 pub type SWR = crate::Reg<swr::SWR_SPEC>;
 #[doc = "Interrupt Status Clear"]
 pub mod swr;
+#[doc = "STC register accessor: an alias for `Reg<STC_SPEC>`"]
+pub type STC = crate::Reg<stc::STC_SPEC>;
+#[doc = "Shadow transfer control"]
+pub mod stc;
+#[doc = "ECRD0 register accessor: an alias for `Reg<ECRD0_SPEC>`"]
+pub type ECRD0 = crate::Reg<ecrd0::ECRD0_SPEC>;
+#[doc = "Extended Read Back 0"]
+pub mod ecrd0;
+#[doc = "ECRD1 register accessor: an alias for `Reg<ECRD1_SPEC>`"]
+pub type ECRD1 = crate::Reg<ecrd1::ECRD1_SPEC>;
+#[doc = "Extended Read Back 1"]
+pub mod ecrd1;
