@@ -1953,6 +1953,8 @@ pub enum STOS_A {
     VALUE2 = 1,
     #[doc = "2: CC8yST1 AND CC8yST2 forward to CCU8x.STy"]
     VALUE3 = 2,
+    #[doc = "3: CC8yST1 OR CC8yST2 forward to CCU8x.STy"]
+    VALUE4 = 3,
 }
 impl From<STOS_A> for u8 {
     #[inline(always)]
@@ -1968,12 +1970,13 @@ impl STOS_R {
     }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> Option<STOS_A> {
+    pub fn variant(&self) -> STOS_A {
         match self.bits {
-            0 => Some(STOS_A::VALUE1),
-            1 => Some(STOS_A::VALUE2),
-            2 => Some(STOS_A::VALUE3),
-            _ => None,
+            0 => STOS_A::VALUE1,
+            1 => STOS_A::VALUE2,
+            2 => STOS_A::VALUE3,
+            3 => STOS_A::VALUE4,
+            _ => unreachable!(),
         }
     }
     #[doc = "Checks if the value of the field is `VALUE1`"]
@@ -1991,6 +1994,11 @@ impl STOS_R {
     pub fn is_value3(&self) -> bool {
         **self == STOS_A::VALUE3
     }
+    #[doc = "Checks if the value of the field is `VALUE4`"]
+    #[inline(always)]
+    pub fn is_value4(&self) -> bool {
+        **self == STOS_A::VALUE4
+    }
 }
 impl core::ops::Deref for STOS_R {
     type Target = crate::FieldReader<u8, STOS_A>;
@@ -2007,7 +2015,7 @@ impl<'a> STOS_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: STOS_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
+        self.bits(variant.into())
     }
     #[doc = "CC8yST1 forward to CCU8x.STy"]
     #[inline(always)]
@@ -2024,9 +2032,14 @@ impl<'a> STOS_W<'a> {
     pub fn value3(self) -> &'a mut W {
         self.variant(STOS_A::VALUE3)
     }
+    #[doc = "CC8yST1 OR CC8yST2 forward to CCU8x.STy"]
+    #[inline(always)]
+    pub fn value4(self) -> &'a mut W {
+        self.variant(STOS_A::VALUE4)
+    }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
+    pub fn bits(self, value: u8) -> &'a mut W {
         self.w.bits = (self.w.bits & !(0x03 << 29)) | ((value as u32 & 0x03) << 29);
         self.w
     }
