@@ -203,13 +203,13 @@ impl<'a> DSWC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
 pub enum ITRMODE_A {
-    #[doc = "0: No integration trigger, integrator bypassed"]
+    #[doc = "0: No integration trigger, integrator bypassed, INTEN = 0 all the time"]
     VALUE1 = 0,
     #[doc = "1: Trigger event upon a falling edge"]
     VALUE2 = 1,
     #[doc = "2: Trigger event upon a rising edge"]
     VALUE3 = 2,
-    #[doc = "3: No trigger, integrator active all the time"]
+    #[doc = "3: No trigger, integrator active all the time, INTEN = 1 all the time"]
     VALUE4 = 3,
 }
 impl From<ITRMODE_A> for u8 {
@@ -273,7 +273,7 @@ impl<'a> ITRMODE_W<'a> {
     pub fn variant(self, variant: ITRMODE_A) -> &'a mut W {
         self.bits(variant.into())
     }
-    #[doc = "No integration trigger, integrator bypassed"]
+    #[doc = "No integration trigger, integrator bypassed, INTEN = 0 all the time"]
     #[inline(always)]
     pub fn value1(self) -> &'a mut W {
         self.variant(ITRMODE_A::VALUE1)
@@ -288,7 +288,7 @@ impl<'a> ITRMODE_W<'a> {
     pub fn value3(self) -> &'a mut W {
         self.variant(ITRMODE_A::VALUE3)
     }
-    #[doc = "No trigger, integrator active all the time"]
+    #[doc = "No trigger, integrator active all the time, INTEN = 1 all the time"]
     #[inline(always)]
     pub fn value4(self) -> &'a mut W {
         self.variant(ITRMODE_A::VALUE4)
@@ -486,8 +486,12 @@ pub enum CSRC_A {
     VALUE2 = 1,
     #[doc = "2: External, from input B"]
     VALUE3 = 2,
+    #[doc = "3: External, from input C"]
+    VALUE4 = 3,
+    #[doc = "4: External, from input D"]
+    VALUE5 = 4,
     #[doc = "15: Internal clock"]
-    VALUE4 = 15,
+    VALUE6 = 15,
 }
 impl From<CSRC_A> for u8 {
     #[inline(always)]
@@ -507,7 +511,9 @@ impl CSRC_R {
         match self.bits {
             1 => Some(CSRC_A::VALUE2),
             2 => Some(CSRC_A::VALUE3),
-            15 => Some(CSRC_A::VALUE4),
+            3 => Some(CSRC_A::VALUE4),
+            4 => Some(CSRC_A::VALUE5),
+            15 => Some(CSRC_A::VALUE6),
             _ => None,
         }
     }
@@ -526,6 +532,16 @@ impl CSRC_R {
     pub fn is_value4(&self) -> bool {
         **self == CSRC_A::VALUE4
     }
+    #[doc = "Checks if the value of the field is `VALUE5`"]
+    #[inline(always)]
+    pub fn is_value5(&self) -> bool {
+        **self == CSRC_A::VALUE5
+    }
+    #[doc = "Checks if the value of the field is `VALUE6`"]
+    #[inline(always)]
+    pub fn is_value6(&self) -> bool {
+        **self == CSRC_A::VALUE6
+    }
 }
 impl core::ops::Deref for CSRC_R {
     type Target = crate::FieldReader<u8, CSRC_A>;
@@ -554,11 +570,21 @@ impl<'a> CSRC_W<'a> {
     pub fn value3(self) -> &'a mut W {
         self.variant(CSRC_A::VALUE3)
     }
-    #[doc = "Internal clock"]
+    #[doc = "External, from input C"]
     #[inline(always)]
     pub fn value4(self) -> &'a mut W {
         self.variant(CSRC_A::VALUE4)
     }
+    #[doc = "External, from input D"]
+    #[inline(always)]
+    pub fn value5(self) -> &'a mut W {
+        self.variant(CSRC_A::VALUE5)
+    }
+    #[doc = "Internal clock"]
+    #[inline(always)]
+    pub fn value6(self) -> &'a mut W {
+        self.variant(CSRC_A::VALUE6)
+    }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
