@@ -519,6 +519,98 @@ impl core::ops::Deref for S10_S11L_R {
         &self.0
     }
 }
+#[doc = "Sectors 12 and 13 Locked for Write Protection by User 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S12_S13L_A {
+    #[doc = "0: No write protection is configured for sectors 12+13."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sectors 12+13."]
+    VALUE2 = 1,
+}
+impl From<S12_S13L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S12_S13L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S12_S13L` reader - Sectors 12 and 13 Locked for Write Protection by User 0"]
+pub struct S12_S13L_R(crate::FieldReader<bool, S12_S13L_A>);
+impl S12_S13L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S12_S13L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S12_S13L_A {
+        match self.bits {
+            false => S12_S13L_A::VALUE1,
+            true => S12_S13L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S12_S13L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S12_S13L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S12_S13L_R {
+    type Target = crate::FieldReader<bool, S12_S13L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Sectors 14 and 15 Locked for Write Protection by User 0\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S14_S15L_A {
+    #[doc = "0: No write protection is configured for sectors 14+15."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sectors 14+15."]
+    VALUE2 = 1,
+}
+impl From<S14_S15L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S14_S15L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S14_S15L` reader - Sectors 14 and 15 Locked for Write Protection by User 0"]
+pub struct S14_S15L_R(crate::FieldReader<bool, S14_S15L_A>);
+impl S14_S15L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S14_S15L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S14_S15L_A {
+        match self.bits {
+            false => S14_S15L_A::VALUE1,
+            true => S14_S15L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S14_S15L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S14_S15L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S14_S15L_R {
+    type Target = crate::FieldReader<bool, S14_S15L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Read Protection Configuration\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RPRO_A {
@@ -621,6 +713,16 @@ impl R {
     pub fn s10_s11l(&self) -> S10_S11L_R {
         S10_S11L_R::new(((self.bits >> 10) & 0x01) != 0)
     }
+    #[doc = "Bit 11 - Sectors 12 and 13 Locked for Write Protection by User 0"]
+    #[inline(always)]
+    pub fn s12_s13l(&self) -> S12_S13L_R {
+        S12_S13L_R::new(((self.bits >> 11) & 0x01) != 0)
+    }
+    #[doc = "Bit 12 - Sectors 14 and 15 Locked for Write Protection by User 0"]
+    #[inline(always)]
+    pub fn s14_s15l(&self) -> S14_S15L_R {
+        S14_S15L_R::new(((self.bits >> 12) & 0x01) != 0)
+    }
     #[doc = "Bit 15 - Read Protection Configuration"]
     #[inline(always)]
     pub fn rpro(&self) -> RPRO_R {
