@@ -519,6 +519,144 @@ impl core::ops::Deref for S10_S11L_R {
         &self.0
     }
 }
+#[doc = "Sectors 12 and 13 Locked for Write Protection by User 1\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S12_S13L_A {
+    #[doc = "0: No write protection is configured for sectors 12+13."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sectors 12+13."]
+    VALUE2 = 1,
+}
+impl From<S12_S13L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S12_S13L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S12_S13L` reader - Sectors 12 and 13 Locked for Write Protection by User 1"]
+pub struct S12_S13L_R(crate::FieldReader<bool, S12_S13L_A>);
+impl S12_S13L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S12_S13L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S12_S13L_A {
+        match self.bits {
+            false => S12_S13L_A::VALUE1,
+            true => S12_S13L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S12_S13L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S12_S13L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S12_S13L_R {
+    type Target = crate::FieldReader<bool, S12_S13L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Sectors 14 and 15 Locked for Write Protection by User 1\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S14_S15L_A {
+    #[doc = "0: No write protection is configured for sectors 14+15."]
+    VALUE1 = 0,
+    #[doc = "1: Write protection is configured for sectors 14+15."]
+    VALUE2 = 1,
+}
+impl From<S14_S15L_A> for bool {
+    #[inline(always)]
+    fn from(variant: S14_S15L_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S14_S15L` reader - Sectors 14 and 15 Locked for Write Protection by User 1"]
+pub struct S14_S15L_R(crate::FieldReader<bool, S14_S15L_A>);
+impl S14_S15L_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S14_S15L_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S14_S15L_A {
+        match self.bits {
+            false => S14_S15L_A::VALUE1,
+            true => S14_S15L_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S14_S15L_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S14_S15L_A::VALUE2
+    }
+}
+impl core::ops::Deref for S14_S15L_R {
+    type Target = crate::FieldReader<bool, S14_S15L_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Physical Sector Repair\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PSR_A {
+    #[doc = "0: Physical Sector Repair command disabled; Erase Physical Sector command sequence available."]
+    VALUE1 = 0,
+    #[doc = "1: Physical Sector Repair command sequence enabled; Erase Physical Sector command sequence disabled."]
+    VALUE2 = 1,
+}
+impl From<PSR_A> for bool {
+    #[inline(always)]
+    fn from(variant: PSR_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `PSR` reader - Physical Sector Repair"]
+pub struct PSR_R(crate::FieldReader<bool, PSR_A>);
+impl PSR_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        PSR_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> PSR_A {
+        match self.bits {
+            false => PSR_A::VALUE1,
+            true => PSR_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == PSR_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == PSR_A::VALUE2
+    }
+}
+impl core::ops::Deref for PSR_R {
+    type Target = crate::FieldReader<bool, PSR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 impl R {
     #[doc = "Bit 0 - Sector 0 Locked for Write Protection by User 1"]
     #[inline(always)]
@@ -575,6 +713,21 @@ impl R {
     pub fn s10_s11l(&self) -> S10_S11L_R {
         S10_S11L_R::new(((self.bits >> 10) & 0x01) != 0)
     }
+    #[doc = "Bit 11 - Sectors 12 and 13 Locked for Write Protection by User 1"]
+    #[inline(always)]
+    pub fn s12_s13l(&self) -> S12_S13L_R {
+        S12_S13L_R::new(((self.bits >> 11) & 0x01) != 0)
+    }
+    #[doc = "Bit 12 - Sectors 14 and 15 Locked for Write Protection by User 1"]
+    #[inline(always)]
+    pub fn s14_s15l(&self) -> S14_S15L_R {
+        S14_S15L_R::new(((self.bits >> 12) & 0x01) != 0)
+    }
+    #[doc = "Bit 16 - Physical Sector Repair"]
+    #[inline(always)]
+    pub fn psr(&self) -> PSR_R {
+        PSR_R::new(((self.bits >> 16) & 0x01) != 0)
+    }
 }
 #[doc = "Flash Protection Configuration Register User 1\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [procon1](index.html) module"]
 pub struct PROCON1_SPEC;
