@@ -519,6 +519,98 @@ impl core::ops::Deref for S10_S11ROM_R {
         &self.0
     }
 }
+#[doc = "Sectors 12 and 13 Locked Forever by User 2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S12_S13ROM_A {
+    #[doc = "0: No ROM functionality is configured for sectors 12+13."]
+    VALUE1 = 0,
+    #[doc = "1: ROM functionality is configured for sectors 12+13."]
+    VALUE2 = 1,
+}
+impl From<S12_S13ROM_A> for bool {
+    #[inline(always)]
+    fn from(variant: S12_S13ROM_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S12_S13ROM` reader - Sectors 12 and 13 Locked Forever by User 2"]
+pub struct S12_S13ROM_R(crate::FieldReader<bool, S12_S13ROM_A>);
+impl S12_S13ROM_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S12_S13ROM_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S12_S13ROM_A {
+        match self.bits {
+            false => S12_S13ROM_A::VALUE1,
+            true => S12_S13ROM_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S12_S13ROM_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S12_S13ROM_A::VALUE2
+    }
+}
+impl core::ops::Deref for S12_S13ROM_R {
+    type Target = crate::FieldReader<bool, S12_S13ROM_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Sectors 14 and 15 Locked Forever by User 2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum S14_S15ROM_A {
+    #[doc = "0: No ROM functionality is configured for sectors 14+15."]
+    VALUE1 = 0,
+    #[doc = "1: ROM functionality is configured for sectors 14+15."]
+    VALUE2 = 1,
+}
+impl From<S14_S15ROM_A> for bool {
+    #[inline(always)]
+    fn from(variant: S14_S15ROM_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `S14_S15ROM` reader - Sectors 14 and 15 Locked Forever by User 2"]
+pub struct S14_S15ROM_R(crate::FieldReader<bool, S14_S15ROM_A>);
+impl S14_S15ROM_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        S14_S15ROM_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> S14_S15ROM_A {
+        match self.bits {
+            false => S14_S15ROM_A::VALUE1,
+            true => S14_S15ROM_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == S14_S15ROM_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == S14_S15ROM_A::VALUE2
+    }
+}
+impl core::ops::Deref for S14_S15ROM_R {
+    type Target = crate::FieldReader<bool, S14_S15ROM_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 impl R {
     #[doc = "Bit 0 - Sector 0 Locked Forever by User 2"]
     #[inline(always)]
@@ -575,6 +667,16 @@ impl R {
     pub fn s10_s11rom(&self) -> S10_S11ROM_R {
         S10_S11ROM_R::new(((self.bits >> 10) & 0x01) != 0)
     }
+    #[doc = "Bit 11 - Sectors 12 and 13 Locked Forever by User 2"]
+    #[inline(always)]
+    pub fn s12_s13rom(&self) -> S12_S13ROM_R {
+        S12_S13ROM_R::new(((self.bits >> 11) & 0x01) != 0)
+    }
+    #[doc = "Bit 12 - Sectors 14 and 15 Locked Forever by User 2"]
+    #[inline(always)]
+    pub fn s14_s15rom(&self) -> S14_S15ROM_R {
+        S14_S15ROM_R::new(((self.bits >> 12) & 0x01) != 0)
+    }
 }
 #[doc = "Flash Protection Configuration Register User 2\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [procon2](index.html) module"]
 pub struct PROCON2_SPEC;
