@@ -38,9 +38,9 @@ impl From<crate::W<PPS_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS0_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS0_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PPS0_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS0_A {
         match self.bits {
-            false => PPS0_A::CONST_0,
-            true => PPS0_A::CONST_1,
+            false => PPS0_A::VALUE1,
+            true => PPS0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS0_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS0_R {
@@ -92,13 +92,13 @@ impl<'a> PPS0_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS0_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PPS0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS1_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PPS1_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS1_A {
         match self.bits {
-            false => PPS1_A::CONST_0,
-            true => PPS1_A::CONST_1,
+            false => PPS1_A::VALUE1,
+            true => PPS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS1_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS1_R {
@@ -175,13 +175,13 @@ impl<'a> PPS1_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS1_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> PPS1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS2_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS2_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl PPS2_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS2_A {
         match self.bits {
-            false => PPS2_A::CONST_0,
-            true => PPS2_A::CONST_1,
+            false => PPS2_A::VALUE1,
+            true => PPS2_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS2_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS2_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS2_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS2_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS2_R {
@@ -258,13 +258,13 @@ impl<'a> PPS2_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS2_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS2_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS2_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS2_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> PPS2_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS3_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS3_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl PPS3_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS3_A {
         match self.bits {
-            false => PPS3_A::CONST_0,
-            true => PPS3_A::CONST_1,
+            false => PPS3_A::VALUE1,
+            true => PPS3_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS3_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS3_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS3_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS3_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS3_R {
@@ -341,13 +341,13 @@ impl<'a> PPS3_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS3_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS3_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS3_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS3_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> PPS3_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS4_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS4_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl PPS4_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS4_A {
         match self.bits {
-            false => PPS4_A::CONST_0,
-            true => PPS4_A::CONST_1,
+            false => PPS4_A::VALUE1,
+            true => PPS4_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS4_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS4_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS4_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS4_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS4_R {
@@ -424,13 +424,13 @@ impl<'a> PPS4_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS4_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS4_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS4_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS4_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> PPS4_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS5_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS5_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl PPS5_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS5_A {
         match self.bits {
-            false => PPS5_A::CONST_0,
-            true => PPS5_A::CONST_1,
+            false => PPS5_A::VALUE1,
+            true => PPS5_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS5_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS5_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS5_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS5_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS5_R {
@@ -507,13 +507,13 @@ impl<'a> PPS5_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS5_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS5_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS5_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS5_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> PPS5_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS6_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS6_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl PPS6_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS6_A {
         match self.bits {
-            false => PPS6_A::CONST_0,
-            true => PPS6_A::CONST_1,
+            false => PPS6_A::VALUE1,
+            true => PPS6_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS6_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS6_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS6_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS6_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS6_R {
@@ -590,13 +590,13 @@ impl<'a> PPS6_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS6_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS6_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS6_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS6_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> PPS6_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS7_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS7_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl PPS7_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS7_A {
         match self.bits {
-            false => PPS7_A::CONST_0,
-            true => PPS7_A::CONST_1,
+            false => PPS7_A::VALUE1,
+            true => PPS7_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS7_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS7_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS7_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS7_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS7_R {
@@ -673,13 +673,13 @@ impl<'a> PPS7_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS7_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS7_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS7_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS7_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +702,9 @@ impl<'a> PPS7_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS8_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS8_A> for bool {
     #[inline(always)]
@@ -722,19 +722,19 @@ impl PPS8_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS8_A {
         match self.bits {
-            false => PPS8_A::CONST_0,
-            true => PPS8_A::CONST_1,
+            false => PPS8_A::VALUE1,
+            true => PPS8_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS8_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS8_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS8_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS8_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS8_R {
@@ -756,13 +756,13 @@ impl<'a> PPS8_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS8_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS8_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS8_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS8_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +785,9 @@ impl<'a> PPS8_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS9_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS9_A> for bool {
     #[inline(always)]
@@ -805,19 +805,19 @@ impl PPS9_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS9_A {
         match self.bits {
-            false => PPS9_A::CONST_0,
-            true => PPS9_A::CONST_1,
+            false => PPS9_A::VALUE1,
+            true => PPS9_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS9_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS9_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS9_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS9_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS9_R {
@@ -839,13 +839,13 @@ impl<'a> PPS9_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS9_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS9_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS9_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS9_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +868,9 @@ impl<'a> PPS9_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS10_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS10_A> for bool {
     #[inline(always)]
@@ -888,19 +888,19 @@ impl PPS10_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS10_A {
         match self.bits {
-            false => PPS10_A::CONST_0,
-            true => PPS10_A::CONST_1,
+            false => PPS10_A::VALUE1,
+            true => PPS10_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS10_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS10_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS10_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS10_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS10_R {
@@ -922,13 +922,13 @@ impl<'a> PPS10_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS10_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS10_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS10_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS10_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -951,9 +951,9 @@ impl<'a> PPS10_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS11_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS11_A> for bool {
     #[inline(always)]
@@ -971,19 +971,19 @@ impl PPS11_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS11_A {
         match self.bits {
-            false => PPS11_A::CONST_0,
-            true => PPS11_A::CONST_1,
+            false => PPS11_A::VALUE1,
+            true => PPS11_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS11_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS11_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS11_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS11_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS11_R {
@@ -1005,13 +1005,13 @@ impl<'a> PPS11_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS11_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS11_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS11_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS11_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1034,9 +1034,9 @@ impl<'a> PPS11_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS12_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS12_A> for bool {
     #[inline(always)]
@@ -1054,19 +1054,19 @@ impl PPS12_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS12_A {
         match self.bits {
-            false => PPS12_A::CONST_0,
-            true => PPS12_A::CONST_1,
+            false => PPS12_A::VALUE1,
+            true => PPS12_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS12_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS12_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS12_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS12_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS12_R {
@@ -1088,13 +1088,13 @@ impl<'a> PPS12_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS12_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS12_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS12_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS12_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1117,9 +1117,9 @@ impl<'a> PPS12_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS13_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS13_A> for bool {
     #[inline(always)]
@@ -1137,19 +1137,19 @@ impl PPS13_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS13_A {
         match self.bits {
-            false => PPS13_A::CONST_0,
-            true => PPS13_A::CONST_1,
+            false => PPS13_A::VALUE1,
+            true => PPS13_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS13_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS13_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS13_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS13_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS13_R {
@@ -1171,13 +1171,13 @@ impl<'a> PPS13_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS13_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS13_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS13_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS13_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1200,9 +1200,9 @@ impl<'a> PPS13_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS14_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS14_A> for bool {
     #[inline(always)]
@@ -1220,19 +1220,19 @@ impl PPS14_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS14_A {
         match self.bits {
-            false => PPS14_A::CONST_0,
-            true => PPS14_A::CONST_1,
+            false => PPS14_A::VALUE1,
+            true => PPS14_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS14_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS14_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS14_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS14_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS14_R {
@@ -1254,13 +1254,13 @@ impl<'a> PPS14_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS14_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS14_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS14_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS14_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1283,9 +1283,9 @@ impl<'a> PPS14_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPS15_A {
     #[doc = "0: Pin Power Save of Pn.x is disabled."]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pin Power Save of Pn.x is enabled."]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPS15_A> for bool {
     #[inline(always)]
@@ -1303,19 +1303,19 @@ impl PPS15_R {
     #[inline(always)]
     pub fn variant(&self) -> PPS15_A {
         match self.bits {
-            false => PPS15_A::CONST_0,
-            true => PPS15_A::CONST_1,
+            false => PPS15_A::VALUE1,
+            true => PPS15_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPS15_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPS15_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPS15_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPS15_A::VALUE2
     }
 }
 impl core::ops::Deref for PPS15_R {
@@ -1337,13 +1337,13 @@ impl<'a> PPS15_W<'a> {
     }
     #[doc = "Pin Power Save of Pn.x is disabled."]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPS15_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPS15_A::VALUE1)
     }
     #[doc = "Pin Power Save of Pn.x is enabled."]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPS15_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPS15_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
