@@ -10,16 +10,22 @@ pub struct RegisterBlock {
     pub iocr0: crate::Reg<iocr0::IOCR0_SPEC>,
     #[doc = "0x14 - Port 3 Input/Output Control Register 4"]
     pub iocr4: crate::Reg<iocr4::IOCR4_SPEC>,
-    _reserved4: [u8; 0x0c],
+    #[doc = "0x18 - Port 3 Input/Output Control Register 8"]
+    pub iocr8: crate::Reg<iocr8::IOCR8_SPEC>,
+    #[doc = "0x1c - Port 3 Input/Output Control Register 12"]
+    pub iocr12: crate::Reg<iocr12::IOCR12_SPEC>,
+    _reserved6: [u8; 0x04],
     #[doc = "0x24 - Port 3 Input Register"]
     pub in_: crate::Reg<in_::IN_SPEC>,
-    _reserved5: [u8; 0x18],
+    _reserved7: [u8; 0x18],
     #[doc = "0x40 - Port 3 Pad Driver Mode 0 Register"]
     pub pdr0: crate::Reg<pdr0::PDR0_SPEC>,
-    _reserved6: [u8; 0x1c],
+    #[doc = "0x44 - Port 3 Pad Driver Mode 1 Register"]
+    pub pdr1: crate::Reg<pdr1::PDR1_SPEC>,
+    _reserved9: [u8; 0x18],
     #[doc = "0x60 - Port 3 Pin Function Decision Control Register"]
     pub pdisc: crate::Reg<pdisc::PDISC_SPEC>,
-    _reserved7: [u8; 0x0c],
+    _reserved10: [u8; 0x0c],
     #[doc = "0x70 - Port 3 Pin Power Save Register"]
     pub pps: crate::Reg<pps::PPS_SPEC>,
     #[doc = "0x74 - Port 3 Pin Hardware Select Register"]
@@ -41,6 +47,14 @@ pub mod iocr0;
 pub type IOCR4 = crate::Reg<iocr4::IOCR4_SPEC>;
 #[doc = "Port 3 Input/Output Control Register 4"]
 pub mod iocr4;
+#[doc = "IOCR8 register accessor: an alias for `Reg<IOCR8_SPEC>`"]
+pub type IOCR8 = crate::Reg<iocr8::IOCR8_SPEC>;
+#[doc = "Port 3 Input/Output Control Register 8"]
+pub mod iocr8;
+#[doc = "IOCR12 register accessor: an alias for `Reg<IOCR12_SPEC>`"]
+pub type IOCR12 = crate::Reg<iocr12::IOCR12_SPEC>;
+#[doc = "Port 3 Input/Output Control Register 12"]
+pub mod iocr12;
 #[doc = "IN register accessor: an alias for `Reg<IN_SPEC>`"]
 pub type IN = crate::Reg<in_::IN_SPEC>;
 #[doc = "Port 3 Input Register"]
@@ -49,6 +63,10 @@ pub mod in_;
 pub type PDR0 = crate::Reg<pdr0::PDR0_SPEC>;
 #[doc = "Port 3 Pad Driver Mode 0 Register"]
 pub mod pdr0;
+#[doc = "PDR1 register accessor: an alias for `Reg<PDR1_SPEC>`"]
+pub type PDR1 = crate::Reg<pdr1::PDR1_SPEC>;
+#[doc = "Port 3 Pad Driver Mode 1 Register"]
+pub mod pdr1;
 #[doc = "PDISC register accessor: an alias for `Reg<PDISC_SPEC>`"]
 pub type PDISC = crate::Reg<pdisc::PDISC_SPEC>;
 #[doc = "Port 3 Pin Function Decision Control Register"]
