@@ -23,9 +23,9 @@ impl From<crate::W<CGATSET0_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VADC_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<VADC_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> VADC_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(VADC_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(VADC_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(VADC_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(VADC_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -70,13 +70,64 @@ impl<'a> VADC_W<'a> {
         self.w
     }
 }
+#[doc = "DSD Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum DSD_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<DSD_AW> for bool {
+    #[inline(always)]
+    fn from(variant: DSD_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `DSD` writer - DSD Gating Set"]
+pub struct DSD_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> DSD_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: DSD_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DSD_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DSD_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
+        self.w
+    }
+}
 #[doc = "CCU40 Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCU40_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCU40_AW> for bool {
     #[inline(always)]
@@ -96,13 +147,13 @@ impl<'a> CCU40_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCU40_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU40_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCU40_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU40_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +176,9 @@ impl<'a> CCU40_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCU41_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCU41_AW> for bool {
     #[inline(always)]
@@ -147,13 +198,13 @@ impl<'a> CCU41_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCU41_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU41_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCU41_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU41_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -172,13 +223,64 @@ impl<'a> CCU41_W<'a> {
         self.w
     }
 }
+#[doc = "CCU42 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU42_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<CCU42_AW> for bool {
+    #[inline(always)]
+    fn from(variant: CCU42_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU42` writer - CCU42 Gating Set"]
+pub struct CCU42_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> CCU42_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: CCU42_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU42_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU42_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
+        self.w
+    }
+}
 #[doc = "CCU80 Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCU80_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCU80_AW> for bool {
     #[inline(always)]
@@ -198,13 +300,13 @@ impl<'a> CCU80_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCU80_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU80_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCU80_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU80_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -223,13 +325,64 @@ impl<'a> CCU80_W<'a> {
         self.w
     }
 }
+#[doc = "CCU81 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU81_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<CCU81_AW> for bool {
+    #[inline(always)]
+    fn from(variant: CCU81_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU81` writer - CCU81 Gating Set"]
+pub struct CCU81_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> CCU81_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: CCU81_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU81_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU81_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w
+    }
+}
 #[doc = "POSIF0 Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum POSIF0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<POSIF0_AW> for bool {
     #[inline(always)]
@@ -249,13 +402,13 @@ impl<'a> POSIF0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(POSIF0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(POSIF0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(POSIF0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(POSIF0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -274,13 +427,64 @@ impl<'a> POSIF0_W<'a> {
         self.w
     }
 }
+#[doc = "POSIF1 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum POSIF1_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<POSIF1_AW> for bool {
+    #[inline(always)]
+    fn from(variant: POSIF1_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `POSIF1` writer - POSIF1 Gating Set"]
+pub struct POSIF1_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> POSIF1_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: POSIF1_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(POSIF1_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(POSIF1_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "USIC0 Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC0_AW> for bool {
     #[inline(always)]
@@ -300,13 +504,13 @@ impl<'a> USIC0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USIC0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USIC0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -329,9 +533,9 @@ impl<'a> USIC0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERU1_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ERU1_AW> for bool {
     #[inline(always)]
@@ -351,13 +555,13 @@ impl<'a> ERU1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ERU1_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ERU1_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ERU1_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ERU1_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -382,6 +586,11 @@ impl W {
     pub fn vadc(&mut self) -> VADC_W {
         VADC_W { w: self }
     }
+    #[doc = "Bit 1 - DSD Gating Set"]
+    #[inline(always)]
+    pub fn dsd(&mut self) -> DSD_W {
+        DSD_W { w: self }
+    }
     #[doc = "Bit 2 - CCU40 Gating Set"]
     #[inline(always)]
     pub fn ccu40(&mut self) -> CCU40_W {
@@ -392,16 +601,31 @@ impl W {
     pub fn ccu41(&mut self) -> CCU41_W {
         CCU41_W { w: self }
     }
+    #[doc = "Bit 4 - CCU42 Gating Set"]
+    #[inline(always)]
+    pub fn ccu42(&mut self) -> CCU42_W {
+        CCU42_W { w: self }
+    }
     #[doc = "Bit 7 - CCU80 Gating Set"]
     #[inline(always)]
     pub fn ccu80(&mut self) -> CCU80_W {
         CCU80_W { w: self }
     }
+    #[doc = "Bit 8 - CCU81 Gating Set"]
+    #[inline(always)]
+    pub fn ccu81(&mut self) -> CCU81_W {
+        CCU81_W { w: self }
+    }
     #[doc = "Bit 9 - POSIF0 Gating Set"]
     #[inline(always)]
     pub fn posif0(&mut self) -> POSIF0_W {
         POSIF0_W { w: self }
     }
+    #[doc = "Bit 10 - POSIF1 Gating Set"]
+    #[inline(always)]
+    pub fn posif1(&mut self) -> POSIF1_W {
+        POSIF1_W { w: self }
+    }
     #[doc = "Bit 11 - USIC0 Gating Set"]
     #[inline(always)]
     pub fn usic0(&mut self) -> USIC0_W {
