@@ -19,13 +19,64 @@ impl From<crate::W<CGATSET1_SPEC>> for W {
         W(writer)
     }
 }
+#[doc = "CCU43 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU43_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<CCU43_AW> for bool {
+    #[inline(always)]
+    fn from(variant: CCU43_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU43` writer - CCU43 Gating Set"]
+pub struct CCU43_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> CCU43_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: CCU43_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU43_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU43_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w
+    }
+}
 #[doc = "LEDTS Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LEDTSCU0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LEDTSCU0_AW> for bool {
     #[inline(always)]
@@ -45,13 +96,13 @@ impl<'a> LEDTSCU0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LEDTSCU0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LEDTSCU0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LEDTSCU0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LEDTSCU0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +125,9 @@ impl<'a> LEDTSCU0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MCAN0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MCAN0_AW> for bool {
     #[inline(always)]
@@ -96,13 +147,13 @@ impl<'a> MCAN0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MCAN0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MCAN0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MCAN0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MCAN0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +176,9 @@ impl<'a> MCAN0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DAC_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DAC_AW> for bool {
     #[inline(always)]
@@ -147,13 +198,13 @@ impl<'a> DAC_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DAC_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DAC_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DAC_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DAC_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +227,9 @@ impl<'a> DAC_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCI_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> MMCI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCI_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> MMCI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC1_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC1_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> USIC1_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USIC1_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC1_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USIC1_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC1_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -274,13 +325,64 @@ impl<'a> USIC1_W<'a> {
         self.w
     }
 }
+#[doc = "USIC2 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum USIC2_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<USIC2_AW> for bool {
+    #[inline(always)]
+    fn from(variant: USIC2_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `USIC2` writer - USIC2 Gating Set"]
+pub struct USIC2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> USIC2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: USIC2_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC2_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC2_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w
+    }
+}
 #[doc = "PORTS Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPORTS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPORTS_AW> for bool {
     #[inline(always)]
@@ -300,13 +402,13 @@ impl<'a> PPORTS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPORTS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPORTS_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPORTS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPORTS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -326,6 +428,11 @@ impl<'a> PPORTS_W<'a> {
     }
 }
 impl W {
+    #[doc = "Bit 0 - CCU43 Gating Set"]
+    #[inline(always)]
+    pub fn ccu43(&mut self) -> CCU43_W {
+        CCU43_W { w: self }
+    }
     #[doc = "Bit 3 - LEDTS Gating Set"]
     #[inline(always)]
     pub fn ledtscu0(&mut self) -> LEDTSCU0_W {
@@ -351,6 +458,11 @@ impl W {
     pub fn usic1(&mut self) -> USIC1_W {
         USIC1_W { w: self }
     }
+    #[doc = "Bit 8 - USIC2 Gating Set"]
+    #[inline(always)]
+    pub fn usic2(&mut self) -> USIC2_W {
+        USIC2_W { w: self }
+    }
     #[doc = "Bit 9 - PORTS Gating Set"]
     #[inline(always)]
     pub fn pports(&mut self) -> PPORTS_W {
