@@ -23,9 +23,9 @@ impl From<crate::W<CGATSET2_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDT_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> WDT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDT_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> WDT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> ETH0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> ETH0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DMA0_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DMA0_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> DMA0_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DMA0_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DMA0_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DMA0_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DMA0_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -172,13 +172,64 @@ impl<'a> DMA0_W<'a> {
         self.w
     }
 }
+#[doc = "DMA1 Gating Set\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum DMA1_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Enable gating"]
+    VALUE2 = 1,
+}
+impl From<DMA1_AW> for bool {
+    #[inline(always)]
+    fn from(variant: DMA1_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `DMA1` writer - DMA1 Gating Set"]
+pub struct DMA1_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> DMA1_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: DMA1_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DMA1_AW::VALUE1)
+    }
+    #[doc = "Enable gating"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DMA1_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
+        self.w
+    }
+}
 #[doc = "FCE Gating Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FCE_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<FCE_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> FCE_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(FCE_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(FCE_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(FCE_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(FCE_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> FCE_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USB_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable gating"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USB_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> USB_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USB_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USB_AW::VALUE1)
     }
     #[doc = "Enable gating"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USB_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USB_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -274,57 +325,6 @@ impl<'a> USB_W<'a> {
         self.w
     }
 }
-#[doc = "ECAT0 Gating Set\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0_AW {
-    #[doc = "0: No effect"]
-    CONST_0 = 0,
-    #[doc = "1: Enable gating"]
-    CONST_1 = 1,
-}
-impl From<ECAT0_AW> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0` writer - ECAT0 Gating Set"]
-pub struct ECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ECAT0_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ECAT0_AW::CONST_0)
-    }
-    #[doc = "Enable gating"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ECAT0_AW::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
-        self.w
-    }
-}
 impl W {
     #[doc = "Bit 1 - WDT Gating Set"]
     #[inline(always)]
@@ -341,6 +341,11 @@ impl W {
     pub fn dma0(&mut self) -> DMA0_W {
         DMA0_W { w: self }
     }
+    #[doc = "Bit 5 - DMA1 Gating Set"]
+    #[inline(always)]
+    pub fn dma1(&mut self) -> DMA1_W {
+        DMA1_W { w: self }
+    }
     #[doc = "Bit 6 - FCE Gating Set"]
     #[inline(always)]
     pub fn fce(&mut self) -> FCE_W {
@@ -351,11 +356,6 @@ impl W {
     pub fn usb(&mut self) -> USB_W {
         USB_W { w: self }
     }
-    #[doc = "Bit 10 - ECAT0 Gating Set"]
-    #[inline(always)]
-    pub fn ecat0(&mut self) -> ECAT0_W {
-        ECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
