@@ -13,6 +13,52 @@ impl From<crate::R<CGATSTAT1_SPEC>> for R {
         R(reader)
     }
 }
+#[doc = "CCU43 Gating Status\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU43_A {
+    #[doc = "0: Gating de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Gating asserted"]
+    VALUE2 = 1,
+}
+impl From<CCU43_A> for bool {
+    #[inline(always)]
+    fn from(variant: CCU43_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU43` reader - CCU43 Gating Status"]
+pub struct CCU43_R(crate::FieldReader<bool, CCU43_A>);
+impl CCU43_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        CCU43_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> CCU43_A {
+        match self.bits {
+            false => CCU43_A::VALUE1,
+            true => CCU43_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == CCU43_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == CCU43_A::VALUE2
+    }
+}
+impl core::ops::Deref for CCU43_R {
+    type Target = crate::FieldReader<bool, CCU43_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "LEDTS Gating Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LEDTSCU0_A {
@@ -243,6 +289,52 @@ impl core::ops::Deref for USIC1_R {
         &self.0
     }
 }
+#[doc = "USIC2 Gating Status\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum USIC2_A {
+    #[doc = "0: Gating de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Gating asserted"]
+    VALUE2 = 1,
+}
+impl From<USIC2_A> for bool {
+    #[inline(always)]
+    fn from(variant: USIC2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `USIC2` reader - USIC2 Gating Status"]
+pub struct USIC2_R(crate::FieldReader<bool, USIC2_A>);
+impl USIC2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USIC2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> USIC2_A {
+        match self.bits {
+            false => USIC2_A::VALUE1,
+            true => USIC2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == USIC2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == USIC2_A::VALUE2
+    }
+}
+impl core::ops::Deref for USIC2_R {
+    type Target = crate::FieldReader<bool, USIC2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "PORTS Gating Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPORTS_A {
@@ -290,6 +382,11 @@ impl core::ops::Deref for PPORTS_R {
     }
 }
 impl R {
+    #[doc = "Bit 0 - CCU43 Gating Status"]
+    #[inline(always)]
+    pub fn ccu43(&self) -> CCU43_R {
+        CCU43_R::new((self.bits & 0x01) != 0)
+    }
     #[doc = "Bit 3 - LEDTS Gating Status"]
     #[inline(always)]
     pub fn ledtscu0(&self) -> LEDTSCU0_R {
@@ -315,6 +412,11 @@ impl R {
     pub fn usic1(&self) -> USIC1_R {
         USIC1_R::new(((self.bits >> 7) & 0x01) != 0)
     }
+    #[doc = "Bit 8 - USIC2 Gating Status"]
+    #[inline(always)]
+    pub fn usic2(&self) -> USIC2_R {
+        USIC2_R::new(((self.bits >> 8) & 0x01) != 0)
+    }
     #[doc = "Bit 9 - PORTS Gating Status"]
     #[inline(always)]
     pub fn pports(&self) -> PPORTS_R {
