@@ -17,9 +17,9 @@ impl From<crate::R<CGATSTAT2_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDT_A {
     #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDT_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl WDT_R {
     #[inline(always)]
     pub fn variant(&self) -> WDT_A {
         match self.bits {
-            false => WDT_A::CONST_0,
-            true => WDT_A::CONST_1,
+            false => WDT_A::VALUE1,
+            true => WDT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WDT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WDT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WDT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WDT_A::VALUE2
     }
 }
 impl core::ops::Deref for WDT_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for WDT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0_A {
     #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl ETH0_R {
     #[inline(always)]
     pub fn variant(&self) -> ETH0_A {
         match self.bits {
-            false => ETH0_A::CONST_0,
-            true => ETH0_A::CONST_1,
+            false => ETH0_A::VALUE1,
+            true => ETH0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ETH0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ETH0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ETH0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ETH0_A::VALUE2
     }
 }
 impl core::ops::Deref for ETH0_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for ETH0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DMA0_A {
     #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DMA0_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl DMA0_R {
     #[inline(always)]
     pub fn variant(&self) -> DMA0_A {
         match self.bits {
-            false => DMA0_A::CONST_0,
-            true => DMA0_A::CONST_1,
+            false => DMA0_A::VALUE1,
+            true => DMA0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == DMA0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == DMA0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == DMA0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == DMA0_A::VALUE2
     }
 }
 impl core::ops::Deref for DMA0_R {
@@ -151,13 +151,59 @@ impl core::ops::Deref for DMA0_R {
         &self.0
     }
 }
+#[doc = "DMA1 Gating Status\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum DMA1_A {
+    #[doc = "0: Gating de-asserted"]
+    VALUE1 = 0,
+    #[doc = "1: Gating asserted"]
+    VALUE2 = 1,
+}
+impl From<DMA1_A> for bool {
+    #[inline(always)]
+    fn from(variant: DMA1_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `DMA1` reader - DMA1 Gating Status"]
+pub struct DMA1_R(crate::FieldReader<bool, DMA1_A>);
+impl DMA1_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DMA1_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> DMA1_A {
+        match self.bits {
+            false => DMA1_A::VALUE1,
+            true => DMA1_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == DMA1_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == DMA1_A::VALUE2
+    }
+}
+impl core::ops::Deref for DMA1_R {
+    type Target = crate::FieldReader<bool, DMA1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "FCE Gating Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FCE_A {
     #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<FCE_A> for bool {
     #[inline(always)]
@@ -175,19 +221,19 @@ impl FCE_R {
     #[inline(always)]
     pub fn variant(&self) -> FCE_A {
         match self.bits {
-            false => FCE_A::CONST_0,
-            true => FCE_A::CONST_1,
+            false => FCE_A::VALUE1,
+            true => FCE_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == FCE_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == FCE_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == FCE_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == FCE_A::VALUE2
     }
 }
 impl core::ops::Deref for FCE_R {
@@ -201,9 +247,9 @@ impl core::ops::Deref for FCE_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USB_A {
     #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USB_A> for bool {
     #[inline(always)]
@@ -221,19 +267,19 @@ impl USB_R {
     #[inline(always)]
     pub fn variant(&self) -> USB_A {
         match self.bits {
-            false => USB_A::CONST_0,
-            true => USB_A::CONST_1,
+            false => USB_A::VALUE1,
+            true => USB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USB_A::VALUE2
     }
 }
 impl core::ops::Deref for USB_R {
@@ -243,52 +289,6 @@ impl core::ops::Deref for USB_R {
         &self.0
     }
 }
-#[doc = "ECAT0 Gating Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0_A {
-    #[doc = "0: Gating de-asserted"]
-    CONST_0 = 0,
-    #[doc = "1: Gating asserted"]
-    CONST_1 = 1,
-}
-impl From<ECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0` reader - ECAT0 Gating Status"]
-pub struct ECAT0_R(crate::FieldReader<bool, ECAT0_A>);
-impl ECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ECAT0_A {
-        match self.bits {
-            false => ECAT0_A::CONST_0,
-            true => ECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for ECAT0_R {
-    type Target = crate::FieldReader<bool, ECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
 impl R {
     #[doc = "Bit 1 - WDT Gating Status"]
     #[inline(always)]
@@ -305,6 +305,11 @@ impl R {
     pub fn dma0(&self) -> DMA0_R {
         DMA0_R::new(((self.bits >> 4) & 0x01) != 0)
     }
+    #[doc = "Bit 5 - DMA1 Gating Status"]
+    #[inline(always)]
+    pub fn dma1(&self) -> DMA1_R {
+        DMA1_R::new(((self.bits >> 5) & 0x01) != 0)
+    }
     #[doc = "Bit 6 - FCE Gating Status"]
     #[inline(always)]
     pub fn fce(&self) -> FCE_R {
@@ -315,11 +320,6 @@ impl R {
     pub fn usb(&self) -> USB_R {
         USB_R::new(((self.bits >> 7) & 0x01) != 0)
     }
-    #[doc = "Bit 10 - ECAT0 Gating Status"]
-    #[inline(always)]
-    pub fn ecat0(&self) -> ECAT0_R {
-        ECAT0_R::new(((self.bits >> 10) & 0x01) != 0)
-    }
 }
 #[doc = "Peripheral 2 Clock Gating Status\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cgatstat2](index.html) module"]
 pub struct CGATSTAT2_SPEC;
