@@ -23,9 +23,9 @@ impl From<crate::W<CLKCLR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCDI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Disable clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBCDI_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> USBCDI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBCDI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBCDI_AW::VALUE1)
     }
     #[doc = "Disable clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBCDI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBCDI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> USBCDI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCCDI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Disable clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCCDI_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> MMCCDI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCCDI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCCDI_AW::VALUE1)
     }
     #[doc = "Disable clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCCDI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCCDI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> MMCCDI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0CDI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Disable clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0CDI_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> ETH0CDI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ETH0CDI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ETH0CDI_AW::VALUE1)
     }
     #[doc = "Disable clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ETH0CDI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ETH0CDI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -172,13 +172,64 @@ impl<'a> ETH0CDI_W<'a> {
         self.w
     }
 }
+#[doc = "EBU Clock Disable\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EBUCDI_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Disable clock"]
+    VALUE2 = 1,
+}
+impl From<EBUCDI_AW> for bool {
+    #[inline(always)]
+    fn from(variant: EBUCDI_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EBUCDI` writer - EBU Clock Disable"]
+pub struct EBUCDI_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> EBUCDI_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: EBUCDI_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(EBUCDI_AW::VALUE1)
+    }
+    #[doc = "Disable clock"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(EBUCDI_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
+        self.w
+    }
+}
 #[doc = "CCU Clock Disable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCDI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Disable clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCUCDI_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> CCUCDI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCUCDI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCUCDI_AW::VALUE1)
     }
     #[doc = "Disable clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCUCDI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCUCDI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> CCUCDI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCDI_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Disable clock"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDTCDI_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> WDTCDI_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(WDTCDI_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTCDI_AW::VALUE1)
     }
     #[doc = "Disable clock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(WDTCDI_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTCDI_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -290,6 +341,11 @@ impl W {
     pub fn eth0cdi(&mut self) -> ETH0CDI_W {
         ETH0CDI_W { w: self }
     }
+    #[doc = "Bit 3 - EBU Clock Disable"]
+    #[inline(always)]
+    pub fn ebucdi(&mut self) -> EBUCDI_W {
+        EBUCDI_W { w: self }
+    }
     #[doc = "Bit 4 - CCU Clock Disable"]
     #[inline(always)]
     pub fn ccucdi(&mut self) -> CCUCDI_W {
