@@ -17,9 +17,9 @@ impl From<crate::R<CLKSTAT_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBCST_A {
     #[doc = "0: Clock disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clock enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBCST_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl USBCST_R {
     #[inline(always)]
     pub fn variant(&self) -> USBCST_A {
         match self.bits {
-            false => USBCST_A::CONST_0,
-            true => USBCST_A::CONST_1,
+            false => USBCST_A::VALUE1,
+            true => USBCST_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBCST_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBCST_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBCST_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBCST_A::VALUE2
     }
 }
 impl core::ops::Deref for USBCST_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for USBCST_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCCST_A {
     #[doc = "0: Clock disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clock enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCCST_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl MMCCST_R {
     #[inline(always)]
     pub fn variant(&self) -> MMCCST_A {
         match self.bits {
-            false => MMCCST_A::CONST_0,
-            true => MMCCST_A::CONST_1,
+            false => MMCCST_A::VALUE1,
+            true => MMCCST_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MMCCST_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MMCCST_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MMCCST_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MMCCST_A::VALUE2
     }
 }
 impl core::ops::Deref for MMCCST_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for MMCCST_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ETH0CST_A {
     #[doc = "0: Clock disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clock enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ETH0CST_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl ETH0CST_R {
     #[inline(always)]
     pub fn variant(&self) -> ETH0CST_A {
         match self.bits {
-            false => ETH0CST_A::CONST_0,
-            true => ETH0CST_A::CONST_1,
+            false => ETH0CST_A::VALUE1,
+            true => ETH0CST_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ETH0CST_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ETH0CST_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ETH0CST_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ETH0CST_A::VALUE2
     }
 }
 impl core::ops::Deref for ETH0CST_R {
@@ -151,13 +151,59 @@ impl core::ops::Deref for ETH0CST_R {
         &self.0
     }
 }
+#[doc = "EBU Clock Status\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EBUCST_A {
+    #[doc = "0: Clock disabled"]
+    VALUE1 = 0,
+    #[doc = "1: Clock enabled"]
+    VALUE2 = 1,
+}
+impl From<EBUCST_A> for bool {
+    #[inline(always)]
+    fn from(variant: EBUCST_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EBUCST` reader - EBU Clock Status"]
+pub struct EBUCST_R(crate::FieldReader<bool, EBUCST_A>);
+impl EBUCST_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EBUCST_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> EBUCST_A {
+        match self.bits {
+            false => EBUCST_A::VALUE1,
+            true => EBUCST_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == EBUCST_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == EBUCST_A::VALUE2
+    }
+}
+impl core::ops::Deref for EBUCST_R {
+    type Target = crate::FieldReader<bool, EBUCST_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "CCU Clock Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUCST_A {
     #[doc = "0: Clock disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clock enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<CCUCST_A> for bool {
     #[inline(always)]
@@ -175,19 +221,19 @@ impl CCUCST_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUCST_A {
         match self.bits {
-            false => CCUCST_A::CONST_0,
-            true => CCUCST_A::CONST_1,
+            false => CCUCST_A::VALUE1,
+            true => CCUCST_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == CCUCST_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == CCUCST_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == CCUCST_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == CCUCST_A::VALUE2
     }
 }
 impl core::ops::Deref for CCUCST_R {
@@ -201,9 +247,9 @@ impl core::ops::Deref for CCUCST_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDTCST_A {
     #[doc = "0: Clock disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clock enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<WDTCST_A> for bool {
     #[inline(always)]
@@ -221,19 +267,19 @@ impl WDTCST_R {
     #[inline(always)]
     pub fn variant(&self) -> WDTCST_A {
         match self.bits {
-            false => WDTCST_A::CONST_0,
-            true => WDTCST_A::CONST_1,
+            false => WDTCST_A::VALUE1,
+            true => WDTCST_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == WDTCST_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == WDTCST_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == WDTCST_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == WDTCST_A::VALUE2
     }
 }
 impl core::ops::Deref for WDTCST_R {
@@ -259,6 +305,11 @@ impl R {
     pub fn eth0cst(&self) -> ETH0CST_R {
         ETH0CST_R::new(((self.bits >> 2) & 0x01) != 0)
     }
+    #[doc = "Bit 3 - EBU Clock Status"]
+    #[inline(always)]
+    pub fn ebucst(&self) -> EBUCST_R {
+        EBUCST_R::new(((self.bits >> 3) & 0x01) != 0)
+    }
     #[doc = "Bit 4 - CCU Clock Status"]
     #[inline(always)]
     pub fn ccucst(&self) -> CCUCST_R {
