@@ -39,11 +39,11 @@ impl From<crate::W<EXTCLKCR_SPEC>> for W {
 #[repr(u8)]
 pub enum ECKSEL_A {
     #[doc = "0: fSYS clock"]
-    CONST_00 = 0,
-    #[doc = "2: fUSB clock divided according to ECKDIV bit field configuration"]
-    CONST_10 = 2,
+    VALUE1 = 0,
+    #[doc = "2: fUSB clock"]
+    VALUE3 = 2,
     #[doc = "3: fPLL clock divided according to ECKDIV bit field configuration"]
-    CONST_11 = 3,
+    VALUE4 = 3,
 }
 impl From<ECKSEL_A> for u8 {
     #[inline(always)]
@@ -61,26 +61,26 @@ impl ECKSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<ECKSEL_A> {
         match self.bits {
-            0 => Some(ECKSEL_A::CONST_00),
-            2 => Some(ECKSEL_A::CONST_10),
-            3 => Some(ECKSEL_A::CONST_11),
+            0 => Some(ECKSEL_A::VALUE1),
+            2 => Some(ECKSEL_A::VALUE3),
+            3 => Some(ECKSEL_A::VALUE4),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_00`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_00(&self) -> bool {
-        **self == ECKSEL_A::CONST_00
+    pub fn is_value1(&self) -> bool {
+        **self == ECKSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_10`"]
+    #[doc = "Checks if the value of the field is `VALUE3`"]
     #[inline(always)]
-    pub fn is_const_10(&self) -> bool {
-        **self == ECKSEL_A::CONST_10
+    pub fn is_value3(&self) -> bool {
+        **self == ECKSEL_A::VALUE3
     }
-    #[doc = "Checks if the value of the field is `CONST_11`"]
+    #[doc = "Checks if the value of the field is `VALUE4`"]
     #[inline(always)]
-    pub fn is_const_11(&self) -> bool {
-        **self == ECKSEL_A::CONST_11
+    pub fn is_value4(&self) -> bool {
+        **self == ECKSEL_A::VALUE4
     }
 }
 impl core::ops::Deref for ECKSEL_R {
@@ -102,18 +102,18 @@ impl<'a> ECKSEL_W<'a> {
     }
     #[doc = "fSYS clock"]
     #[inline(always)]
-    pub fn const_00(self) -> &'a mut W {
-        self.variant(ECKSEL_A::CONST_00)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ECKSEL_A::VALUE1)
     }
-    #[doc = "fUSB clock divided according to ECKDIV bit field configuration"]
+    #[doc = "fUSB clock"]
     #[inline(always)]
-    pub fn const_10(self) -> &'a mut W {
-        self.variant(ECKSEL_A::CONST_10)
+    pub fn value3(self) -> &'a mut W {
+        self.variant(ECKSEL_A::VALUE3)
     }
     #[doc = "fPLL clock divided according to ECKDIV bit field configuration"]
     #[inline(always)]
-    pub fn const_11(self) -> &'a mut W {
-        self.variant(ECKSEL_A::CONST_11)
+    pub fn value4(self) -> &'a mut W {
+        self.variant(ECKSEL_A::VALUE4)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
