@@ -63,10 +63,10 @@ impl<'a> SYSDIV_W<'a> {
 #[doc = "System Clock Selection Value\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SYSSEL_A {
-    #[doc = "0: fOFI clock"]
-    CONST_0 = 0,
-    #[doc = "1: fPLL clock"]
-    CONST_1 = 1,
+    #[doc = "0: fOFIclock"]
+    VALUE1 = 0,
+    #[doc = "1: fPLLclock"]
+    VALUE2 = 1,
 }
 impl From<SYSSEL_A> for bool {
     #[inline(always)]
@@ -84,19 +84,19 @@ impl SYSSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> SYSSEL_A {
         match self.bits {
-            false => SYSSEL_A::CONST_0,
-            true => SYSSEL_A::CONST_1,
+            false => SYSSEL_A::VALUE1,
+            true => SYSSEL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SYSSEL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SYSSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SYSSEL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SYSSEL_A::VALUE2
     }
 }
 impl core::ops::Deref for SYSSEL_R {
@@ -116,15 +116,15 @@ impl<'a> SYSSEL_W<'a> {
     pub fn variant(self, variant: SYSSEL_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "fOFI clock"]
+    #[doc = "fOFIclock"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE1)
     }
-    #[doc = "fPLL clock"]
+    #[doc = "fPLLclock"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SYSSEL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SYSSEL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -146,10 +146,10 @@ impl<'a> SYSSEL_W<'a> {
 #[doc = "CPU Clock Divider Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CPUDIV_A {
-    #[doc = "0: fCPU = fSYS"]
-    CONST_0 = 0,
-    #[doc = "1: fCPU = fSYS / 2"]
-    CONST_1 = 1,
+    #[doc = "0: fCPU=fSYS"]
+    VALUE1 = 0,
+    #[doc = "1: fCPU=fSYS/ 2"]
+    VALUE2 = 1,
 }
 impl From<CPUDIV_A> for bool {
     #[inline(always)]
@@ -167,19 +167,19 @@ impl CPUDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> CPUDIV_A {
         match self.bits {
-            false => CPUDIV_A::CONST_0,
-            true => CPUDIV_A::CONST_1,
+            false => CPUDIV_A::VALUE1,
+            true => CPUDIV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == CPUDIV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == CPUDIV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == CPUDIV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == CPUDIV_A::VALUE2
     }
 }
 impl core::ops::Deref for CPUDIV_R {
@@ -199,15 +199,15 @@ impl<'a> CPUDIV_W<'a> {
     pub fn variant(self, variant: CPUDIV_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "fCPU = fSYS"]
+    #[doc = "fCPU=fSYS"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CPUDIV_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CPUDIV_A::VALUE1)
     }
-    #[doc = "fCPU = fSYS / 2"]
+    #[doc = "fCPU=fSYS/ 2"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CPUDIV_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CPUDIV_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -229,10 +229,10 @@ impl<'a> CPUDIV_W<'a> {
 #[doc = "PB Clock Divider Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PBDIV_A {
-    #[doc = "0: fPERIPH = fCPU"]
-    CONST_0 = 0,
-    #[doc = "1: fPERIPH = fCPU / 2"]
-    CONST_1 = 1,
+    #[doc = "0: fPERIPH=fCPU"]
+    VALUE1 = 0,
+    #[doc = "1: fPERIPH=fCPU/ 2"]
+    VALUE2 = 1,
 }
 impl From<PBDIV_A> for bool {
     #[inline(always)]
@@ -250,19 +250,19 @@ impl PBDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> PBDIV_A {
         match self.bits {
-            false => PBDIV_A::CONST_0,
-            true => PBDIV_A::CONST_1,
+            false => PBDIV_A::VALUE1,
+            true => PBDIV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PBDIV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PBDIV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PBDIV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PBDIV_A::VALUE2
     }
 }
 impl core::ops::Deref for PBDIV_R {
@@ -282,15 +282,15 @@ impl<'a> PBDIV_W<'a> {
     pub fn variant(self, variant: PBDIV_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "fPERIPH = fCPU"]
+    #[doc = "fPERIPH=fCPU"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PBDIV_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PBDIV_A::VALUE1)
     }
-    #[doc = "fPERIPH = fCPU / 2"]
+    #[doc = "fPERIPH=fCPU/ 2"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PBDIV_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PBDIV_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -312,10 +312,10 @@ impl<'a> PBDIV_W<'a> {
 #[doc = "CCU Clock Divider Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CCUDIV_A {
-    #[doc = "0: fCCU = fSYS"]
-    CONST_0 = 0,
-    #[doc = "1: fCCU = fSYS / 2"]
-    CONST_1 = 1,
+    #[doc = "0: fCCU=fSYS"]
+    VALUE1 = 0,
+    #[doc = "1: fCCU=fSYS/ 2"]
+    VALUE2 = 1,
 }
 impl From<CCUDIV_A> for bool {
     #[inline(always)]
@@ -333,19 +333,19 @@ impl CCUDIV_R {
     #[inline(always)]
     pub fn variant(&self) -> CCUDIV_A {
         match self.bits {
-            false => CCUDIV_A::CONST_0,
-            true => CCUDIV_A::CONST_1,
+            false => CCUDIV_A::VALUE1,
+            true => CCUDIV_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == CCUDIV_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == CCUDIV_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == CCUDIV_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == CCUDIV_A::VALUE2
     }
 }
 impl core::ops::Deref for CCUDIV_R {
@@ -365,15 +365,15 @@ impl<'a> CCUDIV_W<'a> {
     pub fn variant(self, variant: CCUDIV_A) -> &'a mut W {
         self.bit(variant.into())
     }
-    #[doc = "fCCU = fSYS"]
+    #[doc = "fCCU=fSYS"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(CCUDIV_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCUDIV_A::VALUE1)
     }
-    #[doc = "fCCU = fSYS / 2"]
+    #[doc = "fCCU=fSYS/ 2"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(CCUDIV_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCUDIV_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -422,12 +422,12 @@ impl<'a> WDTDIV_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
 pub enum WDTSEL_A {
-    #[doc = "0: fOFI clock"]
-    CONST_00 = 0,
-    #[doc = "1: fSTDBY clock"]
-    CONST_01 = 1,
-    #[doc = "2: fPLL clock"]
-    CONST_10 = 2,
+    #[doc = "0: fOFIclock"]
+    VALUE1 = 0,
+    #[doc = "1: fSTDBYclock"]
+    VALUE2 = 1,
+    #[doc = "2: fPLLclock"]
+    VALUE3 = 2,
 }
 impl From<WDTSEL_A> for u8 {
     #[inline(always)]
@@ -445,26 +445,26 @@ impl WDTSEL_R {
     #[inline(always)]
     pub fn variant(&self) -> Option<WDTSEL_A> {
         match self.bits {
-            0 => Some(WDTSEL_A::CONST_00),
-            1 => Some(WDTSEL_A::CONST_01),
-            2 => Some(WDTSEL_A::CONST_10),
+            0 => Some(WDTSEL_A::VALUE1),
+            1 => Some(WDTSEL_A::VALUE2),
+            2 => Some(WDTSEL_A::VALUE3),
             _ => None,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_00`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_00(&self) -> bool {
-        **self == WDTSEL_A::CONST_00
+    pub fn is_value1(&self) -> bool {
+        **self == WDTSEL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_01`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_01(&self) -> bool {
-        **self == WDTSEL_A::CONST_01
+    pub fn is_value2(&self) -> bool {
+        **self == WDTSEL_A::VALUE2
     }
-    #[doc = "Checks if the value of the field is `CONST_10`"]
+    #[doc = "Checks if the value of the field is `VALUE3`"]
     #[inline(always)]
-    pub fn is_const_10(&self) -> bool {
-        **self == WDTSEL_A::CONST_10
+    pub fn is_value3(&self) -> bool {
+        **self == WDTSEL_A::VALUE3
     }
 }
 impl core::ops::Deref for WDTSEL_R {
@@ -484,20 +484,20 @@ impl<'a> WDTSEL_W<'a> {
     pub fn variant(self, variant: WDTSEL_A) -> &'a mut W {
         unsafe { self.bits(variant.into()) }
     }
-    #[doc = "fOFI clock"]
+    #[doc = "fOFIclock"]
     #[inline(always)]
-    pub fn const_00(self) -> &'a mut W {
-        self.variant(WDTSEL_A::CONST_00)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(WDTSEL_A::VALUE1)
     }
-    #[doc = "fSTDBY clock"]
+    #[doc = "fSTDBYclock"]
     #[inline(always)]
-    pub fn const_01(self) -> &'a mut W {
-        self.variant(WDTSEL_A::CONST_01)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(WDTSEL_A::VALUE2)
     }
-    #[doc = "fPLL clock"]
+    #[doc = "fPLLclock"]
     #[inline(always)]
-    pub fn const_10(self) -> &'a mut W {
-        self.variant(WDTSEL_A::CONST_10)
+    pub fn value3(self) -> &'a mut W {
+        self.variant(WDTSEL_A::VALUE3)
     }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
@@ -506,6 +506,32 @@ impl<'a> WDTSEL_W<'a> {
         self.w
     }
 }
+#[doc = "Field `EBUDIV` reader - EBU Clock Divider Value"]
+pub struct EBUDIV_R(crate::FieldReader<u8, u8>);
+impl EBUDIV_R {
+    pub(crate) fn new(bits: u8) -> Self {
+        EBUDIV_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for EBUDIV_R {
+    type Target = crate::FieldReader<u8, u8>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EBUDIV` writer - EBU Clock Divider Value"]
+pub struct EBUDIV_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> EBUDIV_W<'a> {
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub unsafe fn bits(self, value: u8) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x3f << 26)) | ((value as u32 & 0x3f) << 26);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bits 0:7 - System Clock Division Value"]
     #[inline(always)]
@@ -542,6 +568,11 @@ impl R {
     pub fn wdtsel(&self) -> WDTSEL_R {
         WDTSEL_R::new(((self.bits >> 24) & 0x03) as u8)
     }
+    #[doc = "Bits 26:31 - EBU Clock Divider Value"]
+    #[inline(always)]
+    pub fn ebudiv(&self) -> EBUDIV_R {
+        EBUDIV_R::new(((self.bits >> 26) & 0x3f) as u8)
+    }
 }
 impl W {
     #[doc = "Bits 0:7 - System Clock Division Value"]
@@ -579,6 +610,11 @@ impl W {
     pub fn wdtsel(&mut self) -> WDTSEL_W {
         WDTSEL_W { w: self }
     }
+    #[doc = "Bits 26:31 - EBU Clock Divider Value"]
+    #[inline(always)]
+    pub fn ebudiv(&mut self) -> EBUDIV_W {
+        EBUDIV_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
