@@ -17,9 +17,9 @@ impl From<crate::R<MIRRSTS_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCLR_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl HDCLR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCLR_A {
         match self.bits {
-            false => HDCLR_A::CONST_0,
-            true => HDCLR_A::CONST_1,
+            false => HDCLR_A::VALUE1,
+            true => HDCLR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCLR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCLR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCLR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCLR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCLR_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for HDCLR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDSET_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl HDSET_R {
     #[inline(always)]
     pub fn variant(&self) -> HDSET_A {
         match self.bits {
-            false => HDSET_A::CONST_0,
-            true => HDSET_A::CONST_1,
+            false => HDSET_A::VALUE1,
+            true => HDSET_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDSET_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDSET_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDSET_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDSET_A::VALUE2
     }
 }
 impl core::ops::Deref for HDSET_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for HDSET_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCR_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl HDCR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCR_A {
         match self.bits {
-            false => HDCR_A::CONST_0,
-            true => HDCR_A::CONST_1,
+            false => HDCR_A::VALUE1,
+            true => HDCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCR_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for HDCR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCSICTRL_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl OSCSICTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCSICTRL_A {
         match self.bits {
-            false => OSCSICTRL_A::CONST_0,
-            true => OSCSICTRL_A::CONST_1,
+            false => OSCSICTRL_A::VALUE1,
+            true => OSCSICTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCSICTRL_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for OSCSICTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCULCTRL_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl OSCULCTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCULCTRL_A {
         match self.bits {
-            false => OSCULCTRL_A::CONST_0,
-            true => OSCULCTRL_A::CONST_1,
+            false => OSCULCTRL_A::VALUE1,
+            true => OSCULCTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCULCTRL_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for OSCULCTRL_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_CTR_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl RTC_CTR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CTR_A {
         match self.bits {
-            false => RTC_CTR_A::CONST_0,
-            true => RTC_CTR_A::CONST_1,
+            false => RTC_CTR_A::VALUE1,
+            true => RTC_CTR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_CTR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_CTR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_CTR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_CTR_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_CTR_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for RTC_CTR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM0_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl RTC_ATIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM0_A {
         match self.bits {
-            false => RTC_ATIM0_A::CONST_0,
-            true => RTC_ATIM0_A::CONST_1,
+            false => RTC_ATIM0_A::VALUE1,
+            true => RTC_ATIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM0_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for RTC_ATIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM1_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl RTC_ATIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM1_A {
         match self.bits {
-            false => RTC_ATIM1_A::CONST_0,
-            true => RTC_ATIM1_A::CONST_1,
+            false => RTC_ATIM1_A::VALUE1,
+            true => RTC_ATIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM1_R {
@@ -385,9 +385,9 @@ impl core::ops::Deref for RTC_ATIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM0_A> for bool {
     #[inline(always)]
@@ -405,19 +405,19 @@ impl RTC_TIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM0_A {
         match self.bits {
-            false => RTC_TIM0_A::CONST_0,
-            true => RTC_TIM0_A::CONST_1,
+            false => RTC_TIM0_A::VALUE1,
+            true => RTC_TIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM0_R {
@@ -431,9 +431,9 @@ impl core::ops::Deref for RTC_TIM0_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM1_A> for bool {
     #[inline(always)]
@@ -451,19 +451,19 @@ impl RTC_TIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM1_A {
         match self.bits {
-            false => RTC_TIM1_A::CONST_0,
-            true => RTC_TIM1_A::CONST_1,
+            false => RTC_TIM1_A::VALUE1,
+            true => RTC_TIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM1_R {
@@ -477,9 +477,9 @@ impl core::ops::Deref for RTC_TIM1_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RMX_A> for bool {
     #[inline(always)]
@@ -497,19 +497,19 @@ impl RMX_R {
     #[inline(always)]
     pub fn variant(&self) -> RMX_A {
         match self.bits {
-            false => RMX_A::CONST_0,
-            true => RMX_A::CONST_1,
+            false => RMX_A::VALUE1,
+            true => RMX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RMX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RMX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RMX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RMX_A::VALUE2
     }
 }
 impl core::ops::Deref for RMX_R {
@@ -523,9 +523,9 @@ impl core::ops::Deref for RMX_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_MSKSR_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_MSKSR_A> for bool {
     #[inline(always)]
@@ -543,19 +543,19 @@ impl RTC_MSKSR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_MSKSR_A {
         match self.bits {
-            false => RTC_MSKSR_A::CONST_0,
-            true => RTC_MSKSR_A::CONST_1,
+            false => RTC_MSKSR_A::VALUE1,
+            true => RTC_MSKSR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_MSKSR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_MSKSR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_MSKSR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_MSKSR_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_MSKSR_R {
@@ -569,9 +569,9 @@ impl core::ops::Deref for RTC_MSKSR_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CLRSR_A {
     #[doc = "0: Ready"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Busy"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_CLRSR_A> for bool {
     #[inline(always)]
@@ -589,19 +589,19 @@ impl RTC_CLRSR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CLRSR_A {
         match self.bits {
-            false => RTC_CLRSR_A::CONST_0,
-            true => RTC_CLRSR_A::CONST_1,
+            false => RTC_CLRSR_A::VALUE1,
+            true => RTC_CLRSR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_CLRSR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_CLRSR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_CLRSR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_CLRSR_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_CLRSR_R {
