@@ -969,6 +969,8 @@ pub enum HIBIO0SEL_A {
     VALUE8 = 13,
     #[doc = "14: Open-drain GPIO output"]
     VALUE9 = 14,
+    #[doc = "15: Analog input"]
+    VALUE10 = 15,
 }
 impl From<HIBIO0SEL_A> for u8 {
     #[inline(always)]
@@ -995,6 +997,7 @@ impl HIBIO0SEL_R {
             12 => Some(HIBIO0SEL_A::VALUE7),
             13 => Some(HIBIO0SEL_A::VALUE8),
             14 => Some(HIBIO0SEL_A::VALUE9),
+            15 => Some(HIBIO0SEL_A::VALUE10),
             _ => None,
         }
     }
@@ -1043,6 +1046,11 @@ impl HIBIO0SEL_R {
     pub fn is_value9(&self) -> bool {
         **self == HIBIO0SEL_A::VALUE9
     }
+    #[doc = "Checks if the value of the field is `VALUE10`"]
+    #[inline(always)]
+    pub fn is_value10(&self) -> bool {
+        **self == HIBIO0SEL_A::VALUE10
+    }
 }
 impl core::ops::Deref for HIBIO0SEL_R {
     type Target = crate::FieldReader<u8, HIBIO0SEL_A>;
@@ -1106,6 +1114,11 @@ impl<'a> HIBIO0SEL_W<'a> {
     pub fn value9(self) -> &'a mut W {
         self.variant(HIBIO0SEL_A::VALUE9)
     }
+    #[doc = "Analog input"]
+    #[inline(always)]
+    pub fn value10(self) -> &'a mut W {
+        self.variant(HIBIO0SEL_A::VALUE10)
+    }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
@@ -1135,6 +1148,8 @@ pub enum HIBIO1SEL_A {
     VALUE8 = 13,
     #[doc = "14: Open-drain GPIO output"]
     VALUE9 = 14,
+    #[doc = "15: Analog input"]
+    VALUE10 = 15,
 }
 impl From<HIBIO1SEL_A> for u8 {
     #[inline(always)]
@@ -1161,6 +1176,7 @@ impl HIBIO1SEL_R {
             12 => Some(HIBIO1SEL_A::VALUE7),
             13 => Some(HIBIO1SEL_A::VALUE8),
             14 => Some(HIBIO1SEL_A::VALUE9),
+            15 => Some(HIBIO1SEL_A::VALUE10),
             _ => None,
         }
     }
@@ -1209,6 +1225,11 @@ impl HIBIO1SEL_R {
     pub fn is_value9(&self) -> bool {
         **self == HIBIO1SEL_A::VALUE9
     }
+    #[doc = "Checks if the value of the field is `VALUE10`"]
+    #[inline(always)]
+    pub fn is_value10(&self) -> bool {
+        **self == HIBIO1SEL_A::VALUE10
+    }
 }
 impl core::ops::Deref for HIBIO1SEL_R {
     type Target = crate::FieldReader<u8, HIBIO1SEL_A>;
@@ -1272,6 +1293,11 @@ impl<'a> HIBIO1SEL_W<'a> {
     pub fn value9(self) -> &'a mut W {
         self.variant(HIBIO1SEL_A::VALUE9)
     }
+    #[doc = "Analog input"]
+    #[inline(always)]
+    pub fn value10(self) -> &'a mut W {
+        self.variant(HIBIO1SEL_A::VALUE10)
+    }
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
