@@ -38,9 +38,9 @@ impl From<crate::W<SRMSK_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PRWARN_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PRWARN_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl PRWARN_R {
     #[inline(always)]
     pub fn variant(&self) -> PRWARN_A {
         match self.bits {
-            false => PRWARN_A::CONST_0,
-            true => PRWARN_A::CONST_1,
+            false => PRWARN_A::VALUE1,
+            true => PRWARN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PRWARN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PRWARN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PRWARN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PRWARN_A::VALUE2
     }
 }
 impl core::ops::Deref for PRWARN_R {
@@ -92,13 +92,13 @@ impl<'a> PRWARN_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PRWARN_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PRWARN_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PRWARN_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PRWARN_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> PRWARN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PI_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PI_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl PI_R {
     #[inline(always)]
     pub fn variant(&self) -> PI_A {
         match self.bits {
-            false => PI_A::CONST_0,
-            true => PI_A::CONST_1,
+            false => PI_A::VALUE1,
+            true => PI_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PI_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PI_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PI_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PI_A::VALUE2
     }
 }
 impl core::ops::Deref for PI_R {
@@ -175,13 +175,13 @@ impl<'a> PI_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PI_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PI_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PI_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PI_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -204,9 +204,9 @@ impl<'a> PI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum AI_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<AI_A> for bool {
     #[inline(always)]
@@ -224,19 +224,19 @@ impl AI_R {
     #[inline(always)]
     pub fn variant(&self) -> AI_A {
         match self.bits {
-            false => AI_A::CONST_0,
-            true => AI_A::CONST_1,
+            false => AI_A::VALUE1,
+            true => AI_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == AI_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == AI_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == AI_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == AI_A::VALUE2
     }
 }
 impl core::ops::Deref for AI_R {
@@ -258,13 +258,13 @@ impl<'a> AI_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(AI_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(AI_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(AI_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(AI_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +287,9 @@ impl<'a> AI_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DLROVR_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DLROVR_A> for bool {
     #[inline(always)]
@@ -307,19 +307,19 @@ impl DLROVR_R {
     #[inline(always)]
     pub fn variant(&self) -> DLROVR_A {
         match self.bits {
-            false => DLROVR_A::CONST_0,
-            true => DLROVR_A::CONST_1,
+            false => DLROVR_A::VALUE1,
+            true => DLROVR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == DLROVR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == DLROVR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == DLROVR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == DLROVR_A::VALUE2
     }
 }
 impl core::ops::Deref for DLROVR_R {
@@ -341,13 +341,13 @@ impl<'a> DLROVR_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DLROVR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DLROVR_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DLROVR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DLROVR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -370,9 +370,9 @@ impl<'a> DLROVR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCLR_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCLR_A> for bool {
     #[inline(always)]
@@ -390,19 +390,19 @@ impl HDCLR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCLR_A {
         match self.bits {
-            false => HDCLR_A::CONST_0,
-            true => HDCLR_A::CONST_1,
+            false => HDCLR_A::VALUE1,
+            true => HDCLR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCLR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCLR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCLR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCLR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCLR_R {
@@ -424,13 +424,13 @@ impl<'a> HDCLR_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDCLR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDCLR_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDCLR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDCLR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +453,9 @@ impl<'a> HDCLR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDSET_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDSET_A> for bool {
     #[inline(always)]
@@ -473,19 +473,19 @@ impl HDSET_R {
     #[inline(always)]
     pub fn variant(&self) -> HDSET_A {
         match self.bits {
-            false => HDSET_A::CONST_0,
-            true => HDSET_A::CONST_1,
+            false => HDSET_A::VALUE1,
+            true => HDSET_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDSET_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDSET_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDSET_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDSET_A::VALUE2
     }
 }
 impl core::ops::Deref for HDSET_R {
@@ -507,13 +507,13 @@ impl<'a> HDSET_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDSET_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDSET_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDSET_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDSET_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +536,9 @@ impl<'a> HDSET_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HDCR_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HDCR_A> for bool {
     #[inline(always)]
@@ -556,19 +556,19 @@ impl HDCR_R {
     #[inline(always)]
     pub fn variant(&self) -> HDCR_A {
         match self.bits {
-            false => HDCR_A::CONST_0,
-            true => HDCR_A::CONST_1,
+            false => HDCR_A::VALUE1,
+            true => HDCR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HDCR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HDCR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HDCR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HDCR_A::VALUE2
     }
 }
 impl core::ops::Deref for HDCR_R {
@@ -590,13 +590,13 @@ impl<'a> HDCR_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HDCR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HDCR_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HDCR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HDCR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +619,9 @@ impl<'a> HDCR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCSICTRL_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCSICTRL_A> for bool {
     #[inline(always)]
@@ -639,19 +639,19 @@ impl OSCSICTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCSICTRL_A {
         match self.bits {
-            false => OSCSICTRL_A::CONST_0,
-            true => OSCSICTRL_A::CONST_1,
+            false => OSCSICTRL_A::VALUE1,
+            true => OSCSICTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCSICTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCSICTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCSICTRL_R {
@@ -673,13 +673,13 @@ impl<'a> OSCSICTRL_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(OSCSICTRL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(OSCSICTRL_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(OSCSICTRL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(OSCSICTRL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +702,9 @@ impl<'a> OSCSICTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum OSCULCTRL_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<OSCULCTRL_A> for bool {
     #[inline(always)]
@@ -722,19 +722,19 @@ impl OSCULCTRL_R {
     #[inline(always)]
     pub fn variant(&self) -> OSCULCTRL_A {
         match self.bits {
-            false => OSCULCTRL_A::CONST_0,
-            true => OSCULCTRL_A::CONST_1,
+            false => OSCULCTRL_A::VALUE1,
+            true => OSCULCTRL_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == OSCULCTRL_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == OSCULCTRL_A::VALUE2
     }
 }
 impl core::ops::Deref for OSCULCTRL_R {
@@ -756,13 +756,13 @@ impl<'a> OSCULCTRL_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(OSCULCTRL_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(OSCULCTRL_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(OSCULCTRL_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(OSCULCTRL_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +785,9 @@ impl<'a> OSCULCTRL_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_CTR_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_CTR_A> for bool {
     #[inline(always)]
@@ -805,19 +805,19 @@ impl RTC_CTR_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_CTR_A {
         match self.bits {
-            false => RTC_CTR_A::CONST_0,
-            true => RTC_CTR_A::CONST_1,
+            false => RTC_CTR_A::VALUE1,
+            true => RTC_CTR_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_CTR_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_CTR_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_CTR_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_CTR_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_CTR_R {
@@ -839,13 +839,13 @@ impl<'a> RTC_CTR_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_CTR_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_CTR_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_CTR_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_CTR_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +868,9 @@ impl<'a> RTC_CTR_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM0_A> for bool {
     #[inline(always)]
@@ -888,19 +888,19 @@ impl RTC_ATIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM0_A {
         match self.bits {
-            false => RTC_ATIM0_A::CONST_0,
-            true => RTC_ATIM0_A::CONST_1,
+            false => RTC_ATIM0_A::VALUE1,
+            true => RTC_ATIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM0_R {
@@ -922,13 +922,13 @@ impl<'a> RTC_ATIM0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_ATIM0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_ATIM0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -951,9 +951,9 @@ impl<'a> RTC_ATIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_ATIM1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_ATIM1_A> for bool {
     #[inline(always)]
@@ -971,19 +971,19 @@ impl RTC_ATIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_ATIM1_A {
         match self.bits {
-            false => RTC_ATIM1_A::CONST_0,
-            true => RTC_ATIM1_A::CONST_1,
+            false => RTC_ATIM1_A::VALUE1,
+            true => RTC_ATIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_ATIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_ATIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_ATIM1_R {
@@ -1005,13 +1005,13 @@ impl<'a> RTC_ATIM1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_ATIM1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_ATIM1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1034,9 +1034,9 @@ impl<'a> RTC_ATIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM0_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM0_A> for bool {
     #[inline(always)]
@@ -1054,19 +1054,19 @@ impl RTC_TIM0_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM0_A {
         match self.bits {
-            false => RTC_TIM0_A::CONST_0,
-            true => RTC_TIM0_A::CONST_1,
+            false => RTC_TIM0_A::VALUE1,
+            true => RTC_TIM0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM0_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM0_R {
@@ -1088,13 +1088,13 @@ impl<'a> RTC_TIM0_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_TIM0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_TIM0_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_TIM0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_TIM0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1117,9 +1117,9 @@ impl<'a> RTC_TIM0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RTC_TIM1_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RTC_TIM1_A> for bool {
     #[inline(always)]
@@ -1137,19 +1137,19 @@ impl RTC_TIM1_R {
     #[inline(always)]
     pub fn variant(&self) -> RTC_TIM1_A {
         match self.bits {
-            false => RTC_TIM1_A::CONST_0,
-            true => RTC_TIM1_A::CONST_1,
+            false => RTC_TIM1_A::VALUE1,
+            true => RTC_TIM1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RTC_TIM1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RTC_TIM1_A::VALUE2
     }
 }
 impl core::ops::Deref for RTC_TIM1_R {
@@ -1171,13 +1171,13 @@ impl<'a> RTC_TIM1_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RTC_TIM1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RTC_TIM1_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RTC_TIM1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RTC_TIM1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -1200,9 +1200,9 @@ impl<'a> RTC_TIM1_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RMX_A {
     #[doc = "0: Disabled"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enabled"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<RMX_A> for bool {
     #[inline(always)]
@@ -1220,19 +1220,19 @@ impl RMX_R {
     #[inline(always)]
     pub fn variant(&self) -> RMX_A {
         match self.bits {
-            false => RMX_A::CONST_0,
-            true => RMX_A::CONST_1,
+            false => RMX_A::VALUE1,
+            true => RMX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == RMX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == RMX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == RMX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == RMX_A::VALUE2
     }
 }
 impl core::ops::Deref for RMX_R {
@@ -1254,13 +1254,13 @@ impl<'a> RMX_W<'a> {
     }
     #[doc = "Disabled"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(RMX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(RMX_A::VALUE1)
     }
     #[doc = "Enabled"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(RMX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(RMX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
