@@ -34,7 +34,7 @@ impl From<crate::W<OSCHPCTRL_SPEC>> for W {
         W(writer)
     }
 }
-#[doc = "XTAL1 Data Enable\n\nValue on reset: 1"]
+#[doc = "XTAL1 Data Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum X1DEN_A {
     #[doc = "0: Bit X1D is not updated"]
@@ -117,7 +117,7 @@ impl<'a> X1DEN_W<'a> {
         self.w
     }
 }
-#[doc = "Shaper Bypass\n\nValue on reset: 1"]
+#[doc = "Shaper Bypass\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SHBY_A {
     #[doc = "0: The shaper is not bypassed"]
@@ -200,6 +200,107 @@ impl<'a> SHBY_W<'a> {
         self.w
     }
 }
+#[doc = "Oscillator Gain Selection\n\nValue on reset: 3"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+#[repr(u8)]
+pub enum GAINSEL_A {
+    #[doc = "0: The gain control is configured for frequencies from 4 MHz to 8 MHz"]
+    VALUE1 = 0,
+    #[doc = "1: The gain control is configured for frequencies from 4 MHz to 16 MHz"]
+    VALUE2 = 1,
+    #[doc = "2: The gain control is configured for frequencies from 4 MHz to 20 MHz"]
+    VALUE3 = 2,
+    #[doc = "3: The gain control is configured for frequencies from 4 MHz to 25 MHz"]
+    VALUE4 = 3,
+}
+impl From<GAINSEL_A> for u8 {
+    #[inline(always)]
+    fn from(variant: GAINSEL_A) -> Self {
+        variant as _
+    }
+}
+#[doc = "Field `GAINSEL` reader - Oscillator Gain Selection"]
+pub struct GAINSEL_R(crate::FieldReader<u8, GAINSEL_A>);
+impl GAINSEL_R {
+    pub(crate) fn new(bits: u8) -> Self {
+        GAINSEL_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> GAINSEL_A {
+        match self.bits {
+            0 => GAINSEL_A::VALUE1,
+            1 => GAINSEL_A::VALUE2,
+            2 => GAINSEL_A::VALUE3,
+            3 => GAINSEL_A::VALUE4,
+            _ => unreachable!(),
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == GAINSEL_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == GAINSEL_A::VALUE2
+    }
+    #[doc = "Checks if the value of the field is `VALUE3`"]
+    #[inline(always)]
+    pub fn is_value3(&self) -> bool {
+        **self == GAINSEL_A::VALUE3
+    }
+    #[doc = "Checks if the value of the field is `VALUE4`"]
+    #[inline(always)]
+    pub fn is_value4(&self) -> bool {
+        **self == GAINSEL_A::VALUE4
+    }
+}
+impl core::ops::Deref for GAINSEL_R {
+    type Target = crate::FieldReader<u8, GAINSEL_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `GAINSEL` writer - Oscillator Gain Selection"]
+pub struct GAINSEL_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> GAINSEL_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: GAINSEL_A) -> &'a mut W {
+        self.bits(variant.into())
+    }
+    #[doc = "The gain control is configured for frequencies from 4 MHz to 8 MHz"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(GAINSEL_A::VALUE1)
+    }
+    #[doc = "The gain control is configured for frequencies from 4 MHz to 16 MHz"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(GAINSEL_A::VALUE2)
+    }
+    #[doc = "The gain control is configured for frequencies from 4 MHz to 20 MHz"]
+    #[inline(always)]
+    pub fn value3(self) -> &'a mut W {
+        self.variant(GAINSEL_A::VALUE3)
+    }
+    #[doc = "The gain control is configured for frequencies from 4 MHz to 25 MHz"]
+    #[inline(always)]
+    pub fn value4(self) -> &'a mut W {
+        self.variant(GAINSEL_A::VALUE4)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bits(self, value: u8) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
+        self.w
+    }
+}
 #[doc = "Oscillator Mode\n\nValue on reset: 3"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
@@ -338,6 +439,11 @@ impl R {
     pub fn shby(&self) -> SHBY_R {
         SHBY_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bits 2:3 - Oscillator Gain Selection"]
+    #[inline(always)]
+    pub fn gainsel(&self) -> GAINSEL_R {
+        GAINSEL_R::new(((self.bits >> 2) & 0x03) as u8)
+    }
     #[doc = "Bits 4:5 - Oscillator Mode"]
     #[inline(always)]
     pub fn mode(&self) -> MODE_R {
@@ -360,6 +466,11 @@ impl W {
     pub fn shby(&mut self) -> SHBY_W {
         SHBY_W { w: self }
     }
+    #[doc = "Bits 2:3 - Oscillator Gain Selection"]
+    #[inline(always)]
+    pub fn gainsel(&mut self) -> GAINSEL_W {
+        GAINSEL_W { w: self }
+    }
     #[doc = "Bits 4:5 - Oscillator Mode"]
     #[inline(always)]
     pub fn mode(&mut self) -> MODE_W {
@@ -390,10 +501,10 @@ impl crate::Readable for OSCHPCTRL_SPEC {
 impl crate::Writable for OSCHPCTRL_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets OSCHPCTRL to value 0x33"]
+#[doc = "`reset()` method sets OSCHPCTRL to value 0x3c"]
 impl crate::Resettable for OSCHPCTRL_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x33
+        0x3c
     }
 }
