@@ -38,9 +38,9 @@ impl From<crate::W<MCHKCON_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELPS_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELPS_A> for bool {
     #[inline(always)]
@@ -58,19 +58,19 @@ impl SELPS_R {
     #[inline(always)]
     pub fn variant(&self) -> SELPS_A {
         match self.bits {
-            false => SELPS_A::CONST_0,
-            true => SELPS_A::CONST_1,
+            false => SELPS_A::VALUE1,
+            true => SELPS_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELPS_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELPS_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELPS_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELPS_A::VALUE2
     }
 }
 impl core::ops::Deref for SELPS_R {
@@ -92,13 +92,13 @@ impl<'a> SELPS_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELPS_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELPS_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELPS_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELPS_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -121,9 +121,9 @@ impl<'a> SELPS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELDS1_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELDS1_A> for bool {
     #[inline(always)]
@@ -141,19 +141,19 @@ impl SELDS1_R {
     #[inline(always)]
     pub fn variant(&self) -> SELDS1_A {
         match self.bits {
-            false => SELDS1_A::CONST_0,
-            true => SELDS1_A::CONST_1,
+            false => SELDS1_A::VALUE1,
+            true => SELDS1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELDS1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELDS1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELDS1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELDS1_A::VALUE2
     }
 }
 impl core::ops::Deref for SELDS1_R {
@@ -175,13 +175,13 @@ impl<'a> SELDS1_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELDS1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELDS1_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELDS1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELDS1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -200,13 +200,96 @@ impl<'a> SELDS1_W<'a> {
         self.w
     }
 }
+#[doc = "Select Memory Check for DSRAM2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum SELDS2_A {
+    #[doc = "0: Not selected"]
+    VALUE1 = 0,
+    #[doc = "1: Selected"]
+    VALUE2 = 1,
+}
+impl From<SELDS2_A> for bool {
+    #[inline(always)]
+    fn from(variant: SELDS2_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `SELDS2` reader - Select Memory Check for DSRAM2"]
+pub struct SELDS2_R(crate::FieldReader<bool, SELDS2_A>);
+impl SELDS2_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        SELDS2_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> SELDS2_A {
+        match self.bits {
+            false => SELDS2_A::VALUE1,
+            true => SELDS2_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == SELDS2_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == SELDS2_A::VALUE2
+    }
+}
+impl core::ops::Deref for SELDS2_R {
+    type Target = crate::FieldReader<bool, SELDS2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SELDS2` writer - Select Memory Check for DSRAM2"]
+pub struct SELDS2_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> SELDS2_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: SELDS2_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Not selected"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELDS2_A::VALUE1)
+    }
+    #[doc = "Selected"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELDS2_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
+        self.w
+    }
+}
 #[doc = "Select Memory Check for USIC0\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC0DRA_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC0DRA_A> for bool {
     #[inline(always)]
@@ -224,19 +307,19 @@ impl USIC0DRA_R {
     #[inline(always)]
     pub fn variant(&self) -> USIC0DRA_A {
         match self.bits {
-            false => USIC0DRA_A::CONST_0,
-            true => USIC0DRA_A::CONST_1,
+            false => USIC0DRA_A::VALUE1,
+            true => USIC0DRA_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USIC0DRA_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USIC0DRA_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USIC0DRA_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USIC0DRA_A::VALUE2
     }
 }
 impl core::ops::Deref for USIC0DRA_R {
@@ -258,13 +341,13 @@ impl<'a> USIC0DRA_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USIC0DRA_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC0DRA_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USIC0DRA_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC0DRA_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -287,9 +370,9 @@ impl<'a> USIC0DRA_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC1DRA_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC1DRA_A> for bool {
     #[inline(always)]
@@ -307,19 +390,19 @@ impl USIC1DRA_R {
     #[inline(always)]
     pub fn variant(&self) -> USIC1DRA_A {
         match self.bits {
-            false => USIC1DRA_A::CONST_0,
-            true => USIC1DRA_A::CONST_1,
+            false => USIC1DRA_A::VALUE1,
+            true => USIC1DRA_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USIC1DRA_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USIC1DRA_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USIC1DRA_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USIC1DRA_A::VALUE2
     }
 }
 impl core::ops::Deref for USIC1DRA_R {
@@ -341,13 +424,13 @@ impl<'a> USIC1DRA_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USIC1DRA_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC1DRA_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USIC1DRA_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC1DRA_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -366,13 +449,96 @@ impl<'a> USIC1DRA_W<'a> {
         self.w
     }
 }
+#[doc = "Select Memory Check for USIC2\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum USIC2DRA_A {
+    #[doc = "0: Not selected"]
+    VALUE1 = 0,
+    #[doc = "1: Selected"]
+    VALUE2 = 1,
+}
+impl From<USIC2DRA_A> for bool {
+    #[inline(always)]
+    fn from(variant: USIC2DRA_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `USIC2DRA` reader - Select Memory Check for USIC2"]
+pub struct USIC2DRA_R(crate::FieldReader<bool, USIC2DRA_A>);
+impl USIC2DRA_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        USIC2DRA_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> USIC2DRA_A {
+        match self.bits {
+            false => USIC2DRA_A::VALUE1,
+            true => USIC2DRA_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == USIC2DRA_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == USIC2DRA_A::VALUE2
+    }
+}
+impl core::ops::Deref for USIC2DRA_R {
+    type Target = crate::FieldReader<bool, USIC2DRA_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `USIC2DRA` writer - Select Memory Check for USIC2"]
+pub struct USIC2DRA_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> USIC2DRA_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: USIC2DRA_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "Not selected"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC2DRA_A::VALUE1)
+    }
+    #[doc = "Selected"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC2DRA_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
+        self.w
+    }
+}
 #[doc = "Select Memory Check for MultiCAN\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MCANDRA_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MCANDRA_A> for bool {
     #[inline(always)]
@@ -390,19 +556,19 @@ impl MCANDRA_R {
     #[inline(always)]
     pub fn variant(&self) -> MCANDRA_A {
         match self.bits {
-            false => MCANDRA_A::CONST_0,
-            true => MCANDRA_A::CONST_1,
+            false => MCANDRA_A::VALUE1,
+            true => MCANDRA_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == MCANDRA_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == MCANDRA_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == MCANDRA_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == MCANDRA_A::VALUE2
     }
 }
 impl core::ops::Deref for MCANDRA_R {
@@ -424,13 +590,13 @@ impl<'a> MCANDRA_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MCANDRA_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MCANDRA_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MCANDRA_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MCANDRA_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -453,9 +619,9 @@ impl<'a> MCANDRA_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPRFDRA_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPRFDRA_A> for bool {
     #[inline(always)]
@@ -473,19 +639,19 @@ impl PPRFDRA_R {
     #[inline(always)]
     pub fn variant(&self) -> PPRFDRA_A {
         match self.bits {
-            false => PPRFDRA_A::CONST_0,
-            true => PPRFDRA_A::CONST_1,
+            false => PPRFDRA_A::VALUE1,
+            true => PPRFDRA_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PPRFDRA_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PPRFDRA_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PPRFDRA_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PPRFDRA_A::VALUE2
     }
 }
 impl core::ops::Deref for PPRFDRA_R {
@@ -507,13 +673,13 @@ impl<'a> PPRFDRA_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPRFDRA_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPRFDRA_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPRFDRA_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPRFDRA_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -536,9 +702,9 @@ impl<'a> PPRFDRA_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELUSB_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELUSB_A> for bool {
     #[inline(always)]
@@ -556,19 +722,19 @@ impl SELUSB_R {
     #[inline(always)]
     pub fn variant(&self) -> SELUSB_A {
         match self.bits {
-            false => SELUSB_A::CONST_0,
-            true => SELUSB_A::CONST_1,
+            false => SELUSB_A::VALUE1,
+            true => SELUSB_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELUSB_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELUSB_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELUSB_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELUSB_A::VALUE2
     }
 }
 impl core::ops::Deref for SELUSB_R {
@@ -590,13 +756,13 @@ impl<'a> SELUSB_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELUSB_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELUSB_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELUSB_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELUSB_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -619,9 +785,9 @@ impl<'a> SELUSB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELETH0TX_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELETH0TX_A> for bool {
     #[inline(always)]
@@ -639,19 +805,19 @@ impl SELETH0TX_R {
     #[inline(always)]
     pub fn variant(&self) -> SELETH0TX_A {
         match self.bits {
-            false => SELETH0TX_A::CONST_0,
-            true => SELETH0TX_A::CONST_1,
+            false => SELETH0TX_A::VALUE1,
+            true => SELETH0TX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELETH0TX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELETH0TX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELETH0TX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELETH0TX_A::VALUE2
     }
 }
 impl core::ops::Deref for SELETH0TX_R {
@@ -673,13 +839,13 @@ impl<'a> SELETH0TX_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELETH0TX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELETH0TX_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELETH0TX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELETH0TX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -702,9 +868,9 @@ impl<'a> SELETH0TX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELETH0RX_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELETH0RX_A> for bool {
     #[inline(always)]
@@ -722,19 +888,19 @@ impl SELETH0RX_R {
     #[inline(always)]
     pub fn variant(&self) -> SELETH0RX_A {
         match self.bits {
-            false => SELETH0RX_A::CONST_0,
-            true => SELETH0RX_A::CONST_1,
+            false => SELETH0RX_A::VALUE1,
+            true => SELETH0RX_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELETH0RX_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELETH0RX_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELETH0RX_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELETH0RX_A::VALUE2
     }
 }
 impl core::ops::Deref for SELETH0RX_R {
@@ -756,13 +922,13 @@ impl<'a> SELETH0RX_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELETH0RX_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELETH0RX_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELETH0RX_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELETH0RX_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -785,9 +951,9 @@ impl<'a> SELETH0RX_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELSD0_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELSD0_A> for bool {
     #[inline(always)]
@@ -805,19 +971,19 @@ impl SELSD0_R {
     #[inline(always)]
     pub fn variant(&self) -> SELSD0_A {
         match self.bits {
-            false => SELSD0_A::CONST_0,
-            true => SELSD0_A::CONST_1,
+            false => SELSD0_A::VALUE1,
+            true => SELSD0_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELSD0_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELSD0_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELSD0_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELSD0_A::VALUE2
     }
 }
 impl core::ops::Deref for SELSD0_R {
@@ -839,13 +1005,13 @@ impl<'a> SELSD0_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELSD0_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELSD0_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELSD0_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELSD0_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -868,9 +1034,9 @@ impl<'a> SELSD0_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SELSD1_A {
     #[doc = "0: Not selected"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Selected"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SELSD1_A> for bool {
     #[inline(always)]
@@ -888,19 +1054,19 @@ impl SELSD1_R {
     #[inline(always)]
     pub fn variant(&self) -> SELSD1_A {
         match self.bits {
-            false => SELSD1_A::CONST_0,
-            true => SELSD1_A::CONST_1,
+            false => SELSD1_A::VALUE1,
+            true => SELSD1_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELSD1_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SELSD1_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELSD1_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SELSD1_A::VALUE2
     }
 }
 impl core::ops::Deref for SELSD1_R {
@@ -922,13 +1088,13 @@ impl<'a> SELSD1_W<'a> {
     }
     #[doc = "Not selected"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELSD1_A::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SELSD1_A::VALUE1)
     }
     #[doc = "Selected"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELSD1_A::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SELSD1_A::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -947,89 +1113,6 @@ impl<'a> SELSD1_W<'a> {
         self.w
     }
 }
-#[doc = "Select Memory Check for ECAT0 SRAM 1\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum SELECAT0_A {
-    #[doc = "0: Not selected"]
-    CONST_0 = 0,
-    #[doc = "1: Selected"]
-    CONST_1 = 1,
-}
-impl From<SELECAT0_A> for bool {
-    #[inline(always)]
-    fn from(variant: SELECAT0_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `SELECAT0` reader - Select Memory Check for ECAT0 SRAM 1"]
-pub struct SELECAT0_R(crate::FieldReader<bool, SELECAT0_A>);
-impl SELECAT0_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        SELECAT0_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> SELECAT0_A {
-        match self.bits {
-            false => SELECAT0_A::CONST_0,
-            true => SELECAT0_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SELECAT0_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SELECAT0_A::CONST_1
-    }
-}
-impl core::ops::Deref for SELECAT0_R {
-    type Target = crate::FieldReader<bool, SELECAT0_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Field `SELECAT0` writer - Select Memory Check for ECAT0 SRAM 1"]
-pub struct SELECAT0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> SELECAT0_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SELECAT0_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "Not selected"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SELECAT0_A::CONST_0)
-    }
-    #[doc = "Selected"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SELECAT0_A::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
-}
 impl R {
     #[doc = "Bit 0 - Select Memory Check for PSRAM"]
     #[inline(always)]
@@ -1041,6 +1124,11 @@ impl R {
     pub fn selds1(&self) -> SELDS1_R {
         SELDS1_R::new(((self.bits >> 1) & 0x01) != 0)
     }
+    #[doc = "Bit 2 - Select Memory Check for DSRAM2"]
+    #[inline(always)]
+    pub fn selds2(&self) -> SELDS2_R {
+        SELDS2_R::new(((self.bits >> 2) & 0x01) != 0)
+    }
     #[doc = "Bit 8 - Select Memory Check for USIC0"]
     #[inline(always)]
     pub fn usic0dra(&self) -> USIC0DRA_R {
@@ -1051,6 +1139,11 @@ impl R {
     pub fn usic1dra(&self) -> USIC1DRA_R {
         USIC1DRA_R::new(((self.bits >> 9) & 0x01) != 0)
     }
+    #[doc = "Bit 10 - Select Memory Check for USIC2"]
+    #[inline(always)]
+    pub fn usic2dra(&self) -> USIC2DRA_R {
+        USIC2DRA_R::new(((self.bits >> 10) & 0x01) != 0)
+    }
     #[doc = "Bit 12 - Select Memory Check for MultiCAN"]
     #[inline(always)]
     pub fn mcandra(&self) -> MCANDRA_R {
@@ -1086,11 +1179,6 @@ impl R {
     pub fn selsd1(&self) -> SELSD1_R {
         SELSD1_R::new(((self.bits >> 20) & 0x01) != 0)
     }
-    #[doc = "Bit 24 - Select Memory Check for ECAT0 SRAM 1"]
-    #[inline(always)]
-    pub fn selecat0(&self) -> SELECAT0_R {
-        SELECAT0_R::new(((self.bits >> 24) & 0x01) != 0)
-    }
 }
 impl W {
     #[doc = "Bit 0 - Select Memory Check for PSRAM"]
@@ -1103,6 +1191,11 @@ impl W {
     pub fn selds1(&mut self) -> SELDS1_W {
         SELDS1_W { w: self }
     }
+    #[doc = "Bit 2 - Select Memory Check for DSRAM2"]
+    #[inline(always)]
+    pub fn selds2(&mut self) -> SELDS2_W {
+        SELDS2_W { w: self }
+    }
     #[doc = "Bit 8 - Select Memory Check for USIC0"]
     #[inline(always)]
     pub fn usic0dra(&mut self) -> USIC0DRA_W {
@@ -1113,6 +1206,11 @@ impl W {
     pub fn usic1dra(&mut self) -> USIC1DRA_W {
         USIC1DRA_W { w: self }
     }
+    #[doc = "Bit 10 - Select Memory Check for USIC2"]
+    #[inline(always)]
+    pub fn usic2dra(&mut self) -> USIC2DRA_W {
+        USIC2DRA_W { w: self }
+    }
     #[doc = "Bit 12 - Select Memory Check for MultiCAN"]
     #[inline(always)]
     pub fn mcandra(&mut self) -> MCANDRA_W {
@@ -1148,11 +1246,6 @@ impl W {
     pub fn selsd1(&mut self) -> SELSD1_W {
         SELSD1_W { w: self }
     }
-    #[doc = "Bit 24 - Select Memory Check for ECAT0 SRAM 1"]
-    #[inline(always)]
-    pub fn selecat0(&mut self) -> SELECAT0_W {
-        SELECAT0_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
