@@ -23,9 +23,9 @@ impl From<crate::W<PWRSET_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIB_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Enable Hibernate domain"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIB_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> HIB_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(HIB_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(HIB_AW::VALUE1)
     }
     #[doc = "Enable Hibernate domain"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(HIB_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(HIB_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> HIB_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBPHYPDQ_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBPHYPDQ_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> USBPHYPDQ_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBPHYPDQ_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBPHYPDQ_AW::VALUE1)
     }
     #[doc = "Active"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBPHYPDQ_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBPHYPDQ_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> USBPHYPDQ_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBOTGEN_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBOTGEN_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> USBOTGEN_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBOTGEN_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBOTGEN_AW::VALUE1)
     }
     #[doc = "Active"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBOTGEN_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBOTGEN_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +176,9 @@ impl<'a> USBOTGEN_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBPUWQ_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pull-up not active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBPUWQ_AW> for bool {
     #[inline(always)]
@@ -198,13 +198,13 @@ impl<'a> USBPUWQ_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USBPUWQ_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USBPUWQ_AW::VALUE1)
     }
     #[doc = "Pull-up not active"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USBPUWQ_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USBPUWQ_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
