@@ -17,9 +17,9 @@ impl From<crate::R<PWRSTAT_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum HIBEN_A {
     #[doc = "0: Inactive"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<HIBEN_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl HIBEN_R {
     #[inline(always)]
     pub fn variant(&self) -> HIBEN_A {
         match self.bits {
-            false => HIBEN_A::CONST_0,
-            true => HIBEN_A::CONST_1,
+            false => HIBEN_A::VALUE1,
+            true => HIBEN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == HIBEN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == HIBEN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == HIBEN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == HIBEN_A::VALUE2
     }
 }
 impl core::ops::Deref for HIBEN_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for HIBEN_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBPHYPDQ_A {
     #[doc = "0: Power-down"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBPHYPDQ_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl USBPHYPDQ_R {
     #[inline(always)]
     pub fn variant(&self) -> USBPHYPDQ_A {
         match self.bits {
-            false => USBPHYPDQ_A::CONST_0,
-            true => USBPHYPDQ_A::CONST_1,
+            false => USBPHYPDQ_A::VALUE1,
+            true => USBPHYPDQ_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBPHYPDQ_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBPHYPDQ_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBPHYPDQ_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBPHYPDQ_A::VALUE2
     }
 }
 impl core::ops::Deref for USBPHYPDQ_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for USBPHYPDQ_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBOTGEN_A {
     #[doc = "0: Power-down"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBOTGEN_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl USBOTGEN_R {
     #[inline(always)]
     pub fn variant(&self) -> USBOTGEN_A {
         match self.bits {
-            false => USBOTGEN_A::CONST_0,
-            true => USBOTGEN_A::CONST_1,
+            false => USBOTGEN_A::VALUE1,
+            true => USBOTGEN_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBOTGEN_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBOTGEN_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBOTGEN_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBOTGEN_A::VALUE2
     }
 }
 impl core::ops::Deref for USBOTGEN_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for USBOTGEN_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USBPUWQ_A {
     #[doc = "0: Pull-up active"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pull-up not active"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USBPUWQ_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl USBPUWQ_R {
     #[inline(always)]
     pub fn variant(&self) -> USBPUWQ_A {
         match self.bits {
-            false => USBPUWQ_A::CONST_0,
-            true => USBPUWQ_A::CONST_1,
+            false => USBPUWQ_A::VALUE1,
+            true => USBPUWQ_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == USBPUWQ_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == USBPUWQ_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == USBPUWQ_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == USBPUWQ_A::VALUE2
     }
 }
 impl core::ops::Deref for USBPUWQ_R {
