@@ -19,13 +19,64 @@ impl From<crate::W<PRSET1_SPEC>> for W {
         W(writer)
     }
 }
+#[doc = "CCU43 Reset Assert\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum CCU43RS_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Assert reset"]
+    VALUE2 = 1,
+}
+impl From<CCU43RS_AW> for bool {
+    #[inline(always)]
+    fn from(variant: CCU43RS_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `CCU43RS` writer - CCU43 Reset Assert"]
+pub struct CCU43RS_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> CCU43RS_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: CCU43RS_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(CCU43RS_AW::VALUE1)
+    }
+    #[doc = "Assert reset"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(CCU43RS_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
+        self.w
+    }
+}
 #[doc = "LEDTS Reset Assert\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum LEDTSCU0RS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<LEDTSCU0RS_AW> for bool {
     #[inline(always)]
@@ -45,13 +96,13 @@ impl<'a> LEDTSCU0RS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(LEDTSCU0RS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(LEDTSCU0RS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(LEDTSCU0RS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(LEDTSCU0RS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +125,9 @@ impl<'a> LEDTSCU0RS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MCAN0RS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MCAN0RS_AW> for bool {
     #[inline(always)]
@@ -96,13 +147,13 @@ impl<'a> MCAN0RS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MCAN0RS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MCAN0RS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MCAN0RS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MCAN0RS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +176,9 @@ impl<'a> MCAN0RS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum DACRS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<DACRS_AW> for bool {
     #[inline(always)]
@@ -147,13 +198,13 @@ impl<'a> DACRS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(DACRS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(DACRS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(DACRS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(DACRS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +227,9 @@ impl<'a> DACRS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum MMCIRS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<MMCIRS_AW> for bool {
     #[inline(always)]
@@ -198,13 +249,13 @@ impl<'a> MMCIRS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(MMCIRS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(MMCIRS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(MMCIRS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(MMCIRS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +278,9 @@ impl<'a> MMCIRS_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum USIC1RS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<USIC1RS_AW> for bool {
     #[inline(always)]
@@ -249,13 +300,13 @@ impl<'a> USIC1RS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(USIC1RS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC1RS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(USIC1RS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC1RS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -274,13 +325,64 @@ impl<'a> USIC1RS_W<'a> {
         self.w
     }
 }
+#[doc = "USIC2 Reset Assert\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum USIC2RS_AW {
+    #[doc = "0: No effect"]
+    VALUE1 = 0,
+    #[doc = "1: Assert reset"]
+    VALUE2 = 1,
+}
+impl From<USIC2RS_AW> for bool {
+    #[inline(always)]
+    fn from(variant: USIC2RS_AW) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `USIC2RS` writer - USIC2 Reset Assert"]
+pub struct USIC2RS_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> USIC2RS_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: USIC2RS_AW) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "No effect"]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(USIC2RS_AW::VALUE1)
+    }
+    #[doc = "Assert reset"]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(USIC2RS_AW::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
+        self.w
+    }
+}
 #[doc = "PORTS Reset Assert\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PPORTSRS_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Assert reset"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PPORTSRS_AW> for bool {
     #[inline(always)]
@@ -300,13 +402,13 @@ impl<'a> PPORTSRS_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PPORTSRS_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PPORTSRS_AW::VALUE1)
     }
     #[doc = "Assert reset"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PPORTSRS_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PPORTSRS_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -326,6 +428,11 @@ impl<'a> PPORTSRS_W<'a> {
     }
 }
 impl W {
+    #[doc = "Bit 0 - CCU43 Reset Assert"]
+    #[inline(always)]
+    pub fn ccu43rs(&mut self) -> CCU43RS_W {
+        CCU43RS_W { w: self }
+    }
     #[doc = "Bit 3 - LEDTS Reset Assert"]
     #[inline(always)]
     pub fn ledtscu0rs(&mut self) -> LEDTSCU0RS_W {
@@ -351,6 +458,11 @@ impl W {
     pub fn usic1rs(&mut self) -> USIC1RS_W {
         USIC1RS_W { w: self }
     }
+    #[doc = "Bit 8 - USIC2 Reset Assert"]
+    #[inline(always)]
+    pub fn usic2rs(&mut self) -> USIC2RS_W {
+        USIC2RS_W { w: self }
+    }
     #[doc = "Bit 9 - PORTS Reset Assert"]
     #[inline(always)]
     pub fn pportsrs(&mut self) -> PPORTSRS_W {
