@@ -23,9 +23,9 @@ impl From<crate::W<TRAPCLR_SPEC>> for W {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SOSCWDGT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SOSCWDGT_AW> for bool {
     #[inline(always)]
@@ -45,13 +45,13 @@ impl<'a> SOSCWDGT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SOSCWDGT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SOSCWDGT_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SOSCWDGT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SOSCWDGT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -74,9 +74,9 @@ impl<'a> SOSCWDGT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SVCOLCKT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SVCOLCKT_AW> for bool {
     #[inline(always)]
@@ -96,13 +96,13 @@ impl<'a> SVCOLCKT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(SVCOLCKT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(SVCOLCKT_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(SVCOLCKT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(SVCOLCKT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -125,9 +125,9 @@ impl<'a> SVCOLCKT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum UVCOLCKT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<UVCOLCKT_AW> for bool {
     #[inline(always)]
@@ -147,13 +147,13 @@ impl<'a> UVCOLCKT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(UVCOLCKT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(UVCOLCKT_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(UVCOLCKT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(UVCOLCKT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -176,9 +176,9 @@ impl<'a> UVCOLCKT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PET_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PET_AW> for bool {
     #[inline(always)]
@@ -198,13 +198,13 @@ impl<'a> PET_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(PET_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(PET_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(PET_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(PET_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -227,9 +227,9 @@ impl<'a> PET_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BRWNT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BRWNT_AW> for bool {
     #[inline(always)]
@@ -249,13 +249,13 @@ impl<'a> BRWNT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(BRWNT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(BRWNT_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(BRWNT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(BRWNT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -278,9 +278,9 @@ impl<'a> BRWNT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDGT_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ULPWDGT_AW> for bool {
     #[inline(always)]
@@ -300,13 +300,13 @@ impl<'a> ULPWDGT_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ULPWDGT_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(ULPWDGT_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ULPWDGT_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(ULPWDGT_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -329,9 +329,9 @@ impl<'a> ULPWDGT_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR0T_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BWERR0T_AW> for bool {
     #[inline(always)]
@@ -351,13 +351,13 @@ impl<'a> BWERR0T_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(BWERR0T_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(BWERR0T_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(BWERR0T_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(BWERR0T_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -380,9 +380,9 @@ impl<'a> BWERR0T_W<'a> {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR1T_AW {
     #[doc = "0: No effect"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Clear trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BWERR1T_AW> for bool {
     #[inline(always)]
@@ -402,13 +402,13 @@ impl<'a> BWERR1T_W<'a> {
     }
     #[doc = "No effect"]
     #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(BWERR1T_AW::CONST_0)
+    pub fn value1(self) -> &'a mut W {
+        self.variant(BWERR1T_AW::VALUE1)
     }
     #[doc = "Clear trap request"]
     #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(BWERR1T_AW::CONST_1)
+    pub fn value2(self) -> &'a mut W {
+        self.variant(BWERR1T_AW::VALUE2)
     }
     #[doc = r"Sets the field bit"]
     #[inline(always)]
@@ -427,57 +427,6 @@ impl<'a> BWERR1T_W<'a> {
         self.w
     }
 }
-#[doc = "EtherCat Reset 0 Trap Clear\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0RST_AW {
-    #[doc = "0: No effect"]
-    CONST_0 = 0,
-    #[doc = "1: Set trap request"]
-    CONST_1 = 1,
-}
-impl From<ECAT0RST_AW> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0RST_AW) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0RST` writer - EtherCat Reset 0 Trap Clear"]
-pub struct ECAT0RST_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ECAT0RST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ECAT0RST_AW) -> &'a mut W {
-        self.bit(variant.into())
-    }
-    #[doc = "No effect"]
-    #[inline(always)]
-    pub fn const_0(self) -> &'a mut W {
-        self.variant(ECAT0RST_AW::CONST_0)
-    }
-    #[doc = "Set trap request"]
-    #[inline(always)]
-    pub fn const_1(self) -> &'a mut W {
-        self.variant(ECAT0RST_AW::CONST_1)
-    }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
-        self.w
-    }
-}
 impl W {
     #[doc = "Bit 0 - OSC_HP Oscillator Watchdog Trap Clear"]
     #[inline(always)]
@@ -519,11 +468,6 @@ impl W {
     pub fn bwerr1t(&mut self) -> BWERR1T_W {
         BWERR1T_W { w: self }
     }
-    #[doc = "Bit 16 - EtherCat Reset 0 Trap Clear"]
-    #[inline(always)]
-    pub fn ecat0rst(&mut self) -> ECAT0RST_W {
-        ECAT0RST_W { w: self }
-    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
