@@ -801,10 +801,10 @@ impl crate::Readable for TRAPDIS_SPEC {
 impl crate::Writable for TRAPDIS_SPEC {
     type Writer = W;
 }
-#[doc = "`reset()` method sets TRAPDIS to value 0x01ff"]
+#[doc = "`reset()` method sets TRAPDIS to value 0x0001_01fd"]
 impl crate::Resettable for TRAPDIS_SPEC {
     #[inline(always)]
     fn reset_value() -> Self::Ux {
-        0x01ff
+        0x0001_01fd
     }
 }
