@@ -17,9 +17,9 @@ impl From<crate::R<TRAPRAW_SPEC>> for R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SOSCWDGT_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SOSCWDGT_A> for bool {
     #[inline(always)]
@@ -37,19 +37,19 @@ impl SOSCWDGT_R {
     #[inline(always)]
     pub fn variant(&self) -> SOSCWDGT_A {
         match self.bits {
-            false => SOSCWDGT_A::CONST_0,
-            true => SOSCWDGT_A::CONST_1,
+            false => SOSCWDGT_A::VALUE1,
+            true => SOSCWDGT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SOSCWDGT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SOSCWDGT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SOSCWDGT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SOSCWDGT_A::VALUE2
     }
 }
 impl core::ops::Deref for SOSCWDGT_R {
@@ -63,9 +63,9 @@ impl core::ops::Deref for SOSCWDGT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SVCOLCKT_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<SVCOLCKT_A> for bool {
     #[inline(always)]
@@ -83,19 +83,19 @@ impl SVCOLCKT_R {
     #[inline(always)]
     pub fn variant(&self) -> SVCOLCKT_A {
         match self.bits {
-            false => SVCOLCKT_A::CONST_0,
-            true => SVCOLCKT_A::CONST_1,
+            false => SVCOLCKT_A::VALUE1,
+            true => SVCOLCKT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == SVCOLCKT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == SVCOLCKT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == SVCOLCKT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == SVCOLCKT_A::VALUE2
     }
 }
 impl core::ops::Deref for SVCOLCKT_R {
@@ -109,9 +109,9 @@ impl core::ops::Deref for SVCOLCKT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum UVCOLCKT_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<UVCOLCKT_A> for bool {
     #[inline(always)]
@@ -129,19 +129,19 @@ impl UVCOLCKT_R {
     #[inline(always)]
     pub fn variant(&self) -> UVCOLCKT_A {
         match self.bits {
-            false => UVCOLCKT_A::CONST_0,
-            true => UVCOLCKT_A::CONST_1,
+            false => UVCOLCKT_A::VALUE1,
+            true => UVCOLCKT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == UVCOLCKT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == UVCOLCKT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == UVCOLCKT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == UVCOLCKT_A::VALUE2
     }
 }
 impl core::ops::Deref for UVCOLCKT_R {
@@ -155,9 +155,9 @@ impl core::ops::Deref for UVCOLCKT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PET_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<PET_A> for bool {
     #[inline(always)]
@@ -175,19 +175,19 @@ impl PET_R {
     #[inline(always)]
     pub fn variant(&self) -> PET_A {
         match self.bits {
-            false => PET_A::CONST_0,
-            true => PET_A::CONST_1,
+            false => PET_A::VALUE1,
+            true => PET_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == PET_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == PET_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == PET_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == PET_A::VALUE2
     }
 }
 impl core::ops::Deref for PET_R {
@@ -201,9 +201,9 @@ impl core::ops::Deref for PET_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BRWNT_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BRWNT_A> for bool {
     #[inline(always)]
@@ -221,19 +221,19 @@ impl BRWNT_R {
     #[inline(always)]
     pub fn variant(&self) -> BRWNT_A {
         match self.bits {
-            false => BRWNT_A::CONST_0,
-            true => BRWNT_A::CONST_1,
+            false => BRWNT_A::VALUE1,
+            true => BRWNT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == BRWNT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == BRWNT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == BRWNT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == BRWNT_A::VALUE2
     }
 }
 impl core::ops::Deref for BRWNT_R {
@@ -247,9 +247,9 @@ impl core::ops::Deref for BRWNT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ULPWDGT_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<ULPWDGT_A> for bool {
     #[inline(always)]
@@ -267,19 +267,19 @@ impl ULPWDGT_R {
     #[inline(always)]
     pub fn variant(&self) -> ULPWDGT_A {
         match self.bits {
-            false => ULPWDGT_A::CONST_0,
-            true => ULPWDGT_A::CONST_1,
+            false => ULPWDGT_A::VALUE1,
+            true => ULPWDGT_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ULPWDGT_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == ULPWDGT_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ULPWDGT_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == ULPWDGT_A::VALUE2
     }
 }
 impl core::ops::Deref for ULPWDGT_R {
@@ -293,9 +293,9 @@ impl core::ops::Deref for ULPWDGT_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR0T_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BWERR0T_A> for bool {
     #[inline(always)]
@@ -313,19 +313,19 @@ impl BWERR0T_R {
     #[inline(always)]
     pub fn variant(&self) -> BWERR0T_A {
         match self.bits {
-            false => BWERR0T_A::CONST_0,
-            true => BWERR0T_A::CONST_1,
+            false => BWERR0T_A::VALUE1,
+            true => BWERR0T_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == BWERR0T_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == BWERR0T_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == BWERR0T_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == BWERR0T_A::VALUE2
     }
 }
 impl core::ops::Deref for BWERR0T_R {
@@ -339,9 +339,9 @@ impl core::ops::Deref for BWERR0T_R {
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum BWERR1T_A {
     #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
+    VALUE1 = 0,
     #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
+    VALUE2 = 1,
 }
 impl From<BWERR1T_A> for bool {
     #[inline(always)]
@@ -359,19 +359,19 @@ impl BWERR1T_R {
     #[inline(always)]
     pub fn variant(&self) -> BWERR1T_A {
         match self.bits {
-            false => BWERR1T_A::CONST_0,
-            true => BWERR1T_A::CONST_1,
+            false => BWERR1T_A::VALUE1,
+            true => BWERR1T_A::VALUE2,
         }
     }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
+    #[doc = "Checks if the value of the field is `VALUE1`"]
     #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == BWERR1T_A::CONST_0
+    pub fn is_value1(&self) -> bool {
+        **self == BWERR1T_A::VALUE1
     }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
+    #[doc = "Checks if the value of the field is `VALUE2`"]
     #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == BWERR1T_A::CONST_1
+    pub fn is_value2(&self) -> bool {
+        **self == BWERR1T_A::VALUE2
     }
 }
 impl core::ops::Deref for BWERR1T_R {
@@ -381,52 +381,6 @@ impl core::ops::Deref for BWERR1T_R {
         &self.0
     }
 }
-#[doc = "EtherCat Reset 0 Trap Raw Status\n\nValue on reset: 0"]
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum ECAT0RST_A {
-    #[doc = "0: No pending trap request"]
-    CONST_0 = 0,
-    #[doc = "1: Pending trap request"]
-    CONST_1 = 1,
-}
-impl From<ECAT0RST_A> for bool {
-    #[inline(always)]
-    fn from(variant: ECAT0RST_A) -> Self {
-        variant as u8 != 0
-    }
-}
-#[doc = "Field `ECAT0RST` reader - EtherCat Reset 0 Trap Raw Status"]
-pub struct ECAT0RST_R(crate::FieldReader<bool, ECAT0RST_A>);
-impl ECAT0RST_R {
-    pub(crate) fn new(bits: bool) -> Self {
-        ECAT0RST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
-    #[inline(always)]
-    pub fn variant(&self) -> ECAT0RST_A {
-        match self.bits {
-            false => ECAT0RST_A::CONST_0,
-            true => ECAT0RST_A::CONST_1,
-        }
-    }
-    #[doc = "Checks if the value of the field is `CONST_0`"]
-    #[inline(always)]
-    pub fn is_const_0(&self) -> bool {
-        **self == ECAT0RST_A::CONST_0
-    }
-    #[doc = "Checks if the value of the field is `CONST_1`"]
-    #[inline(always)]
-    pub fn is_const_1(&self) -> bool {
-        **self == ECAT0RST_A::CONST_1
-    }
-}
-impl core::ops::Deref for ECAT0RST_R {
-    type Target = crate::FieldReader<bool, ECAT0RST_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
 impl R {
     #[doc = "Bit 0 - OSC_HP Oscillator Watchdog Trap Raw Status"]
     #[inline(always)]
@@ -468,11 +422,6 @@ impl R {
     pub fn bwerr1t(&self) -> BWERR1T_R {
         BWERR1T_R::new(((self.bits >> 8) & 0x01) != 0)
     }
-    #[doc = "Bit 16 - EtherCat Reset 0 Trap Raw Status"]
-    #[inline(always)]
-    pub fn ecat0rst(&self) -> ECAT0RST_R {
-        ECAT0RST_R::new(((self.bits >> 16) & 0x01) != 0)
-    }
 }
 #[doc = "Trap Raw Status Register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [trapraw](index.html) module"]
 pub struct TRAPRAW_SPEC;
