@@ -480,6 +480,89 @@ impl<'a> PTXFEMPLVL_W<'a> {
         self.w
     }
 }
+#[doc = "AHB Single Support\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum AHBSINGLE_A {
+    #[doc = "0: The remaining data in a transfer is sent using INCR burst size. This is the default mode."]
+    VALUE1 = 0,
+    #[doc = "1: The remaining data in a transfer is sent using single burst size."]
+    VALUE2 = 1,
+}
+impl From<AHBSINGLE_A> for bool {
+    #[inline(always)]
+    fn from(variant: AHBSINGLE_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `AHBSingle` reader - AHB Single Support"]
+pub struct AHBSINGLE_R(crate::FieldReader<bool, AHBSINGLE_A>);
+impl AHBSINGLE_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        AHBSINGLE_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> AHBSINGLE_A {
+        match self.bits {
+            false => AHBSINGLE_A::VALUE1,
+            true => AHBSINGLE_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == AHBSINGLE_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == AHBSINGLE_A::VALUE2
+    }
+}
+impl core::ops::Deref for AHBSINGLE_R {
+    type Target = crate::FieldReader<bool, AHBSINGLE_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `AHBSingle` writer - AHB Single Support"]
+pub struct AHBSINGLE_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> AHBSINGLE_W<'a> {
+    #[doc = r"Writes `variant` to the field"]
+    #[inline(always)]
+    pub fn variant(self, variant: AHBSINGLE_A) -> &'a mut W {
+        self.bit(variant.into())
+    }
+    #[doc = "The remaining data in a transfer is sent using INCR burst size. This is the default mode."]
+    #[inline(always)]
+    pub fn value1(self) -> &'a mut W {
+        self.variant(AHBSINGLE_A::VALUE1)
+    }
+    #[doc = "The remaining data in a transfer is sent using single burst size."]
+    #[inline(always)]
+    pub fn value2(self) -> &'a mut W {
+        self.variant(AHBSINGLE_A::VALUE2)
+    }
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
+        self.w
+    }
+}
 impl R {
     #[doc = "Bit 0 - Global Interrupt Mask"]
     #[inline(always)]
@@ -506,6 +589,11 @@ impl R {
     pub fn ptx_femp_lvl(&self) -> PTXFEMPLVL_R {
         PTXFEMPLVL_R::new(((self.bits >> 8) & 0x01) != 0)
     }
+    #[doc = "Bit 23 - AHB Single Support"]
+    #[inline(always)]
+    pub fn ahbsingle(&self) -> AHBSINGLE_R {
+        AHBSINGLE_R::new(((self.bits >> 23) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bit 0 - Global Interrupt Mask"]
@@ -533,6 +621,11 @@ impl W {
     pub fn ptx_femp_lvl(&mut self) -> PTXFEMPLVL_W {
         PTXFEMPLVL_W { w: self }
     }
+    #[doc = "Bit 23 - AHB Single Support"]
+    #[inline(always)]
+    pub fn ahbsingle(&mut self) -> AHBSINGLE_W {
+        AHBSINGLE_W { w: self }
+    }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
     pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
