@@ -646,6 +646,42 @@ impl<'a> CONIDSTSCHNGMSK_W<'a> {
         self.w
     }
 }
+#[doc = "Field `DisconnIntMsk` reader - Disconnect Detected Interrupt Mask"]
+pub struct DISCONNINTMSK_R(crate::FieldReader<bool, bool>);
+impl DISCONNINTMSK_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        DISCONNINTMSK_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for DISCONNINTMSK_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `DisconnIntMsk` writer - Disconnect Detected Interrupt Mask"]
+pub struct DISCONNINTMSK_W<'a> {
+    w: &'a mut W,
+}
+impl<'a> DISCONNINTMSK_W<'a> {
+    #[doc = r"Sets the field bit"]
+    #[inline(always)]
+    pub fn set_bit(self) -> &'a mut W {
+        self.bit(true)
+    }
+    #[doc = r"Clears the field bit"]
+    #[inline(always)]
+    pub fn clear_bit(self) -> &'a mut W {
+        self.bit(false)
+    }
+    #[doc = r"Writes raw bits to the field"]
+    #[inline(always)]
+    pub fn bit(self, value: bool) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x01 << 29)) | ((value as u32 & 0x01) << 29);
+        self.w
+    }
+}
 #[doc = "Field `SessReqIntMsk` reader - Session Request/New Session Detected Interrupt Mask"]
 pub struct SESSREQINTMSK_R(crate::FieldReader<bool, bool>);
 impl SESSREQINTMSK_R {
@@ -804,6 +840,11 @@ impl R {
     pub fn con_idsts_chng_msk(&self) -> CONIDSTSCHNGMSK_R {
         CONIDSTSCHNGMSK_R::new(((self.bits >> 28) & 0x01) != 0)
     }
+    #[doc = "Bit 29 - Disconnect Detected Interrupt Mask"]
+    #[inline(always)]
+    pub fn disconn_int_msk(&self) -> DISCONNINTMSK_R {
+        DISCONNINTMSK_R::new(((self.bits >> 29) & 0x01) != 0)
+    }
     #[doc = "Bit 30 - Session Request/New Session Detected Interrupt Mask"]
     #[inline(always)]
     pub fn sess_req_int_msk(&self) -> SESSREQINTMSK_R {
@@ -901,6 +942,11 @@ impl W {
     pub fn con_idsts_chng_msk(&mut self) -> CONIDSTSCHNGMSK_W {
         CONIDSTSCHNGMSK_W { w: self }
     }
+    #[doc = "Bit 29 - Disconnect Detected Interrupt Mask"]
+    #[inline(always)]
+    pub fn disconn_int_msk(&mut self) -> DISCONNINTMSK_W {
+        DISCONNINTMSK_W { w: self }
+    }
     #[doc = "Bit 30 - Session Request/New Session Detected Interrupt Mask"]
     #[inline(always)]
     pub fn sess_req_int_msk(&mut self) -> SESSREQINTMSK_W {
