@@ -23,7 +23,13 @@ pub struct RegisterBlock {
     _reserved7: [u8; 0x04],
     #[doc = "0xc8 - Boundary Flag Register"]
     pub bfl: crate::Reg<bfl::BFL_SPEC>,
-    _reserved8: [u8; 0x34],
+    #[doc = "0xcc - Boundary Flag Software Register"]
+    pub bfls: crate::Reg<bfls::BFLS_SPEC>,
+    #[doc = "0xd0 - Boundary Flag Control Register"]
+    pub bflc: crate::Reg<bflc::BFLC_SPEC>,
+    #[doc = "0xd4 - Boundary Flag Node Pointer Register"]
+    pub bflnp: crate::Reg<bflnp::BFLNP_SPEC>,
+    _reserved11: [u8; 0x28],
     #[doc = "0x100 - Queue 0 Source Control Register"]
     pub qctrl0: crate::Reg<qctrl0::QCTRL0_SPEC>,
     #[doc = "0x104 - Queue 0 Mode Register"]
@@ -32,8 +38,8 @@ pub struct RegisterBlock {
     pub qsr0: crate::Reg<qsr0::QSR0_SPEC>,
     #[doc = "0x10c - Queue 0 Register 0"]
     pub q0r0: crate::Reg<q0r0::Q0R0_SPEC>,
-    _reserved_12_qbur0: [u8; 0x04],
-    _reserved13: [u8; 0x0c],
+    _reserved_15_qbur0: [u8; 0x04],
+    _reserved16: [u8; 0x0c],
     #[doc = "0x120 - Autoscan Source Control Register"]
     pub asctrl: crate::Reg<asctrl::ASCTRL_SPEC>,
     #[doc = "0x124 - Autoscan Source Mode Register"]
@@ -42,50 +48,50 @@ pub struct RegisterBlock {
     pub assel: crate::Reg<assel::ASSEL_SPEC>,
     #[doc = "0x12c - Autoscan Source Pending Register"]
     pub aspnd: crate::Reg<aspnd::ASPND_SPEC>,
-    _reserved17: [u8; 0x50],
+    _reserved20: [u8; 0x50],
     #[doc = "0x180 - Channel Event Flag Register"]
     pub ceflag: crate::Reg<ceflag::CEFLAG_SPEC>,
     #[doc = "0x184 - Result Event Flag Register"]
     pub reflag: crate::Reg<reflag::REFLAG_SPEC>,
     #[doc = "0x188 - Source Event Flag Register"]
     pub seflag: crate::Reg<seflag::SEFLAG_SPEC>,
-    _reserved20: [u8; 0x04],
+    _reserved23: [u8; 0x04],
     #[doc = "0x190 - Channel Event Flag Clear Register"]
     pub cefclr: crate::Reg<cefclr::CEFCLR_SPEC>,
     #[doc = "0x194 - Result Event Flag Clear Register"]
     pub refclr: crate::Reg<refclr::REFCLR_SPEC>,
     #[doc = "0x198 - Source Event Flag Clear Register"]
     pub sefclr: crate::Reg<sefclr::SEFCLR_SPEC>,
-    _reserved23: [u8; 0x04],
+    _reserved26: [u8; 0x04],
     #[doc = "0x1a0 - Channel Event Node Pointer Register 0"]
     pub cevnp0: crate::Reg<cevnp0::CEVNP0_SPEC>,
-    _reserved24: [u8; 0x0c],
+    _reserved27: [u8; 0x0c],
     #[doc = "0x1b0 - Result Event Node Pointer Register 0"]
     pub revnp0: crate::Reg<revnp0::REVNP0_SPEC>,
     #[doc = "0x1b4 - Result Event Node Pointer Register 1"]
     pub revnp1: crate::Reg<revnp1::REVNP1_SPEC>,
-    _reserved26: [u8; 0x08],
+    _reserved29: [u8; 0x08],
     #[doc = "0x1c0 - Source Event Node Pointer Register"]
     pub sevnp: crate::Reg<sevnp::SEVNP_SPEC>,
-    _reserved27: [u8; 0x04],
+    _reserved30: [u8; 0x04],
     #[doc = "0x1c8 - Service Request Software Activation Trigger"]
     pub sract: crate::Reg<sract::SRACT_SPEC>,
-    _reserved28: [u8; 0x24],
-    #[doc = "0x1f0 - External Multiplexer Control Register"]
+    _reserved31: [u8; 0x24],
+    #[doc = "0x1f0 - E0ternal Multiplexer Control Register"]
     pub emuxctr: crate::Reg<emuxctr::EMUXCTR_SPEC>,
-    _reserved29: [u8; 0x04],
+    _reserved32: [u8; 0x04],
     #[doc = "0x1f8 - Valid Flag Register"]
     pub vfr: crate::Reg<vfr::VFR_SPEC>,
-    _reserved30: [u8; 0x04],
+    _reserved33: [u8; 0x04],
     #[doc = "0x200..0x220 - Channel Ctrl. Reg."]
     pub chctr: [crate::Reg<chctr::CHCTR_SPEC>; 8],
-    _reserved31: [u8; 0x60],
+    _reserved34: [u8; 0x60],
     #[doc = "0x280..0x2c0 - Result Control Register"]
     pub rcr: [crate::Reg<rcr::RCR_SPEC>; 16],
-    _reserved32: [u8; 0x40],
+    _reserved35: [u8; 0x40],
     #[doc = "0x300..0x340 - Result Register"]
     pub res: [crate::Reg<res::RES_SPEC>; 16],
-    _reserved33: [u8; 0x40],
+    _reserved36: [u8; 0x40],
     #[doc = "0x380..0x3c0 - Result Register, Debug"]
     pub resd: [crate::Reg<resd::RESD_SPEC>; 16],
 }
@@ -133,6 +139,18 @@ pub mod synctr;
 pub type BFL = crate::Reg<bfl::BFL_SPEC>;
 #[doc = "Boundary Flag Register"]
 pub mod bfl;
+#[doc = "BFLS register accessor: an alias for `Reg<BFLS_SPEC>`"]
+pub type BFLS = crate::Reg<bfls::BFLS_SPEC>;
+#[doc = "Boundary Flag Software Register"]
+pub mod bfls;
+#[doc = "BFLC register accessor: an alias for `Reg<BFLC_SPEC>`"]
+pub type BFLC = crate::Reg<bflc::BFLC_SPEC>;
+#[doc = "Boundary Flag Control Register"]
+pub mod bflc;
+#[doc = "BFLNP register accessor: an alias for `Reg<BFLNP_SPEC>`"]
+pub type BFLNP = crate::Reg<bflnp::BFLNP_SPEC>;
+#[doc = "Boundary Flag Node Pointer Register"]
+pub mod bflnp;
 #[doc = "QCTRL0 register accessor: an alias for `Reg<QCTRL0_SPEC>`"]
 pub type QCTRL0 = crate::Reg<qctrl0::QCTRL0_SPEC>;
 #[doc = "Queue 0 Source Control Register"]
@@ -219,7 +237,7 @@ pub type SRACT = crate::Reg<sract::SRACT_SPEC>;
 pub mod sract;
 #[doc = "EMUXCTR register accessor: an alias for `Reg<EMUXCTR_SPEC>`"]
 pub type EMUXCTR = crate::Reg<emuxctr::EMUXCTR_SPEC>;
-#[doc = "External Multiplexer Control Register"]
+#[doc = "E0ternal Multiplexer Control Register"]
 pub mod emuxctr;
 #[doc = "VFR register accessor: an alias for `Reg<VFR_SPEC>`"]
 pub type VFR = crate::Reg<vfr::VFR_SPEC>;
