@@ -75,14 +75,14 @@ impl core::ops::Deref for EMUXACT_R {
     }
 }
 #[doc = "Field `EMUXCH` reader - External Multiplexer Channel Select"]
-pub struct EMUXCH_R(crate::FieldReader<u8, u8>);
+pub struct EMUXCH_R(crate::FieldReader<u16, u16>);
 impl EMUXCH_R {
-    pub(crate) fn new(bits: u8) -> Self {
+    pub(crate) fn new(bits: u16) -> Self {
         EMUXCH_R(crate::FieldReader::new(bits))
     }
 }
 impl core::ops::Deref for EMUXCH_R {
-    type Target = crate::FieldReader<u8, u8>;
+    type Target = crate::FieldReader<u16, u16>;
     #[inline(always)]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -95,8 +95,8 @@ pub struct EMUXCH_W<'a> {
 impl<'a> EMUXCH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x1f << 16)) | ((value as u32 & 0x1f) << 16);
+    pub unsafe fn bits(self, value: u16) -> &'a mut W {
+        self.w.bits = (self.w.bits & !(0x03ff << 16)) | ((value as u32 & 0x03ff) << 16);
         self.w
     }
 }
@@ -367,12 +367,58 @@ impl<'a> EMXST_W<'a> {
         self.w
     }
 }
+#[doc = "External Multiplexer Channel Selection Style\n\nValue on reset: 0"]
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum EMXCSS_A {
+    #[doc = "0: Channel number: Bitfield EMUXCH selects an arbitrary channel"]
+    VALUE1 = 0,
+    #[doc = "1: Channel enable: Each bit of bitfield EMUXCH selects the associated channel for EMUX control"]
+    VALUE2 = 1,
+}
+impl From<EMXCSS_A> for bool {
+    #[inline(always)]
+    fn from(variant: EMXCSS_A) -> Self {
+        variant as u8 != 0
+    }
+}
+#[doc = "Field `EMXCSS` reader - External Multiplexer Channel Selection Style"]
+pub struct EMXCSS_R(crate::FieldReader<bool, EMXCSS_A>);
+impl EMXCSS_R {
+    pub(crate) fn new(bits: bool) -> Self {
+        EMXCSS_R(crate::FieldReader::new(bits))
+    }
+    #[doc = r"Get enumerated values variant"]
+    #[inline(always)]
+    pub fn variant(&self) -> EMXCSS_A {
+        match self.bits {
+            false => EMXCSS_A::VALUE1,
+            true => EMXCSS_A::VALUE2,
+        }
+    }
+    #[doc = "Checks if the value of the field is `VALUE1`"]
+    #[inline(always)]
+    pub fn is_value1(&self) -> bool {
+        **self == EMXCSS_A::VALUE1
+    }
+    #[doc = "Checks if the value of the field is `VALUE2`"]
+    #[inline(always)]
+    pub fn is_value2(&self) -> bool {
+        **self == EMXCSS_A::VALUE2
+    }
+}
+impl core::ops::Deref for EMXCSS_R {
+    type Target = crate::FieldReader<bool, EMXCSS_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
 #[doc = "Write Control for EMUX Configuration\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum EMXWC_AW {
     #[doc = "0: No write access to EMUX cfg."]
     VALUE1 = 0,
-    #[doc = "1: Bitfields EMXMODE, EMXCOD, EMXST can be written"]
+    #[doc = "1: Bitfields EMXMODE, EMXCOD, EMXST, EMXCSS can be written"]
     VALUE2 = 1,
 }
 impl From<EMXWC_AW> for bool {
@@ -396,7 +442,7 @@ impl<'a> EMXWC_W<'a> {
     pub fn value1(self) -> &'a mut W {
         self.variant(EMXWC_AW::VALUE1)
     }
-    #[doc = "Bitfields EMXMODE, EMXCOD, EMXST can be written"]
+    #[doc = "Bitfields EMXMODE, EMXCOD, EMXST, EMXCSS can be written"]
     #[inline(always)]
     pub fn value2(self) -> &'a mut W {
         self.variant(EMXWC_AW::VALUE2)
@@ -429,10 +475,10 @@ impl R {
     pub fn emuxact(&self) -> EMUXACT_R {
         EMUXACT_R::new(((self.bits >> 8) & 0x07) as u8)
     }
-    #[doc = "Bits 16:20 - External Multiplexer Channel Select"]
+    #[doc = "Bits 16:25 - External Multiplexer Channel Select"]
     #[inline(always)]
     pub fn emuxch(&self) -> EMUXCH_R {
-        EMUXCH_R::new(((self.bits >> 16) & 0x1f) as u8)
+        EMUXCH_R::new(((self.bits >> 16) & 0x03ff) as u16)
     }
     #[doc = "Bits 26:27 - External Multiplexer Mode"]
     #[inline(always)]
@@ -449,6 +495,11 @@ impl R {
     pub fn emxst(&self) -> EMXST_R {
         EMXST_R::new(((self.bits >> 29) & 0x01) != 0)
     }
+    #[doc = "Bit 30 - External Multiplexer Channel Selection Style"]
+    #[inline(always)]
+    pub fn emxcss(&self) -> EMXCSS_R {
+        EMXCSS_R::new(((self.bits >> 30) & 0x01) != 0)
+    }
 }
 impl W {
     #[doc = "Bits 0:2 - External Multiplexer Start Selection"]
@@ -456,7 +507,7 @@ impl W {
     pub fn emuxset(&mut self) -> EMUXSET_W {
         EMUXSET_W { w: self }
     }
-    #[doc = "Bits 16:20 - External Multiplexer Channel Select"]
+    #[doc = "Bits 16:25 - External Multiplexer Channel Select"]
     #[inline(always)]
     pub fn emuxch(&mut self) -> EMUXCH_W {
         EMUXCH_W { w: self }
@@ -488,7 +539,7 @@ impl W {
         self
     }
 }
-#[doc = "External Multiplexer Control Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [emuxctr](index.html) module"]
+#[doc = "E0ternal Multiplexer Control Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [emuxctr](index.html) module"]
 pub struct EMUXCTR_SPEC;
 impl crate::RegisterSpec for EMUXCTR_SPEC {
     type Ux = u32;
